package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.26.1 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.26.1) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````,``P`!````#!@``#0```!`P0```````#0`(``)
M`"@`&P`:``8````T````-````#0````@`0``(`$```4````$`````P```%0!
M``!4`0``5`$``!,````3````!`````$````!````````````````````8*\`
M`&"O```%`````!````$```"HO0``J,T``*C-``!H`@``K!(```8`````$```
M`@```+"]``"PS0``L,T``"`!```@`0``!@````0````$````:`$``&@!``!H
M`0``1````$0````$````!````%#E=&3`H```P*```,"@``#T````]`````0`
M```$````4>5T9```````````````````````````!@```!````!2Y71DJ+T`
M`*C-``"HS0``6`(``%@"```$`````0```"]L:6(O;&0M;&EN=7@N<V\N,@``
M!````!`````!````1TY5```````"````!@```"`````$````%`````,```!'
M3E4`?AJ[1.7DLB->/&\?QD/<'DQ&J)$1````2P````@````(`````!`0!"5`
M!(`H`0`!H(8`@(`!```+*`0).*`218H$"`@`````2P```$\```!3````5```
M`%H```!;````7````%X```!?`````````&$```!C````9````&4`````````
M`````&[%WQ_JT^\.SMY'+6M_FGPNQ9NV(/_D#KB-\0[59-1\V7%8'.)'Q@&L
M2^/`NN.2?,+E/RSZH6Q@LP&+;VL)0]9GK\QF0D75[(D'<-,-%.*>VLWCGC-B
MV^T,.I<+6>CM['^IG)OAIP(*H^#[20````````````````````"J`@``````
M```````2````6`,`````````````$@```/\!`````````````!(````1````
M```````````@````<0,`````````````$0```.4#`````````````!(```#W
M`@`````````````1````20,`````````````$@```!$!`````````````!(`
M``#%`@`````````````2````M```````````````$@```(,!````````````
M`!(```"Q`@`````````````2````A```````````````$@````P!````````
M`````!(```![`P`````````````2````_@(`````````````$@````$!````
M`````````!$```!Y`@`````````````2````9P$`````````````$@```.,`
M`````````````!$````%`P`````````````2````-0$`````````````$@``
M`,(``````````````!(````L`P`````````````B````L0$`````````````
M$@```$@"`````````````!(```#W`0`````````````2````E0(`````````
M````$@```)X!`````````````!(```"&`@`````````````2````J@$`````
M````````$@```$,!`````````````!(````.`P`````````````2````+0``
M````````````(````%H"`````````````!(```"\`0`````````````1````
M&P,`````````````$@```&0``````````````!(```"C`@`````````````2
M````7P,`````````````$@```/`!`````````````!(```"3````````````
M```2````GP``````````````$@```%P!`````````````!(```"``@``````
M```````2````9P(`````````````$@```"(!`````````````!(````8`@``
M```````````2````C@(`````````````$@```%8``````````````!(````6
M`0`````````````2````S`(`````````````$@```),!`````````````!(`
M``#P```````````````2````40,`````````````$@```)P"````````````
M`!(```!R`P`````````````A````=0$`````````````$@```',`````````
M`````!(```#4```````````````2````4P$`````````````$@```"(#````
M`````````!(```"W`@`````````````2````/```````````````(````%\"
M`````````````!(```!S`P`````````````1````[0(`````````````$@``
M``0"`````````````!(```#:`@`````````````2````*0(`````````````
M$@```'`"`````````````!(```#E`@`````````````2````.P,`````````
M````$@```.X#```P8```;P```!(`#@"\`P``=&$````````2``\`$P0```!0
M``"1#```$@`.`&P#``#0%0``/`(``!(`#@#"`P``0$D```4````2``X`>00`
M`%!)```E`@``$@`.`',$``#`$0```````!(`"P"F!```H%P``(8#```2``X`
MH0,``!#0````````$``8`/H#``"`2P``*@```!(`#@`Y`@``C&$```0````1
M`!``K0,``%3@````````$``8`'$$``#@1P``.P```!(`#@"&!```,$\``,<`
M```2``X`F`0``'!.``!V````$@`.`"`$````T````````!``%P`'!```L$L`
M`.@````2``X`F@,``!#0````````$``7`%,$```,T```!````!$`%P"R`P``
M4&$```(````2``X`0P0``/!@``!=````$@`.`"8$```,&````````!(`#@`B
M!````-`````````@`!<`700``(AA```$````$0`0`-,#``#P3@``-````!(`
M#@`M!```@$@``+D````2``X`9`0``*!,``#$`0``$@`.``!L:6)P97)L+G-O
M+C4N,C8`7TE435]D97)E9VES=&5R5$U#;&]N951A8FQE`%]?9VUO;E]S=&%R
M=%]?`%])5$U?<F5G:7-T97)434-L;VYE5&%B;&4`4&5R;%]S>7-?=&5R;0!0
M97)L7W-Y<U]I;FET,P!097)L7V%T9F]R:U]L;V-K`'!E<FQ?8V]N<W1R=6-T
M`%!E<FQ?9V5T7W-V`%!E<FQ?8W)O86M?;F]C;VYT97AT`%!E<FQ?879?<VAI
M9G0`4&5R;%]S=E\R<'9?9FQA9W,`4&5R;%]S=E]S971P=FX`4$Q?9&]?=6YD
M=6UP`%!E<FQ?;F5W6%-?9FQA9W,`4$Q?=&AR7VME>0!P97)L7V9R964`4&5R
M;%]M9U]S970`4&5R;%]A=&9O<FM?=6YL;V-K`%!E<FQ?<W9?<V5T<'8`4&5R
M;%]G=E]F971C:'!V`'!E<FQ?<G5N`%!E<FQ?;F5W6%,`<&5R;%]D97-T<G5C
M=`!097)L7V%V7V9E=&-H`&)O;W1?1'EN84QO861E<@!P97)L7W!A<G-E`%!E
M<FQ?<V%F97-Y<VUA;&QO8P!P97)L7V%L;&]C`%!,7VUE;6]R>5]W<F%P`&QI
M8F1L+G-O+C(`;&EB;2YS;RXV`&QI8G!T:')E860N<V\N,`!O<&5N-C0`;'-E
M96LV-`!R96%D`'!T:')E861?9V5T<W!E8VEF:6,`7U]E<G)N;U]L;V-A=&EO
M;@!C;&]S90!L:6)C+G-O+C8`7TE/7W-T9&EN7W5S960`7U]R96=I<W1E<E]A
M=&9O<FL`97AI=`!S=')N8VUP`%]?<W1R9'5P`&-L;W-E9&ER`'5N;&EN:P!M
M:V1I<@!R96%L;&]C`&UE;6-H<@!G971P:60`<W1R=&]K`'-T<FQE;@!S=')S
M='(`<FUD:7(`7U]F<')I;G1F7V-H:P!M96UC<'D`7U]S=')N8W!Y7V-H:P!?
M7VQX<W1A=#8T`&]P96YD:7(`7U]X<W1A=#8T`'-T9&5R<@!G971U:60`<F5A
M9&QI;FL`7U]M96UC<'E?8VAK`'-T<F-H<@!R96%D9&ER-C0`7U]C>&%?9FEN
M86QI>F4`7U]S<')I;G1F7V-H:P!M96UM;W9E`&%C8V5S<P!S=')C;7``7U]L
M:6)C7W-T87)T7VUA:6X`7U]E;G9I<F]N`%]?<W1A8VM?8VAK7V9A:6P`;&EB
M8W)Y<'0N<V\N,0!?961A=&$`7U]B<W-?<W1A<G0`7V5N9`!?7VQI8F-?8W-U
M7V9I;FD`<&%R7V-U<G)E;G1?97AE8P!G971?=7-E<FYA;65?9G)O;5]G971P
M=W5I9`!P87)?8VQE86YU<`!P87)?8F%S96YA;64`<&%R7V1I<FYA;64`<&%R
M7VUK=&UP9&ER`%]?9&%T85]S=&%R=`!P87)?8W5R<F5N=%]E>&5C7W!R;V,`
M7U]L:6)C7V-S=5]I;FET`&UY7W!A<E]P;`!?9G!?:'<`<&%R7VEN:71?96YV
M`'AS7VEN:70`<&%R7V9I;F1P<F]G`'!A<E]S971U<%]L:6)P871H`'!A<E]E
M;G9?8VQE86X`6%-?26YT97)N86QS7U!!4E]"3T]4`$=,24)#7S(N,@!'3$E"
M0U\R+C``1TQ)0D-?,BXS+C0`1TQ)0D-?,BXS+C(`1TQ)0D-?,BXQ+C,`1TQ)
M0D-?,BXT`````@`"``,````"``(``@`"``(``@```````@``````!``"````
M`@```````@``````!0````8`!P`"`````@`"````"`````(````"`````@`"
M``<``````````@`"`````P`"```````(```````"``(``@````````````D`
M"`````(``@`)``,`"0`#``(``@`(``$``0`!``$``0`!``$``0`!``$``0`!
M``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!`````0`"`.`!```0````
M,````!)I:0T```<`O`0``!`````0:6D-```#`,8$`````````0`&`"\"```0
M`````````!)I:0T```D`O`0``!````!T&6D)```(`-`$```0````<AEI"0``
M!@#<!```$````',?:0D```4`Z`0``!`````4:6D-```$`/0$```0````$&EI
M#0```@#&!````````*C-```(````K,T```@```#PSP``"`````30```(````
M#-````@```#,SP``!@0``-#/```&!P``U,\```8,``#8SP``!A(``-S/```&
M%0``X,\```89``#DSP``!B,``.C/```&)0``[,\```8P``#TSP``!CP``/C/
M```&00``_,\```9#``#<S@``!P$``.#.```'`@``Y,X```<#``#HS@``!P8`
M`.S.```'"```\,X```<)``#TS@``!PH``/C.```'"P``_,X```<-````SP``
M!PX```3/```'#P``",\```<0```,SP``!Q$``!#/```'$P``%,\```<4```8
MSP``!Q8``!S/```'%P``(,\```<8```DSP``!QH``"C/```'&P``+,\```<<
M```PSP``!QT``#3/```''@``.,\```<?```\SP``!R```$#/```'(0``1,\`
M``<B``!(SP``!R0``$S/```')@``4,\```<G``!4SP``!R@``%C/```'*0``
M7,\```<J``!@SP``!RL``&3/```'+```:,\```<M``!LSP``!RX``'#/```'
M+P``=,\```<Q``!XSP``!S(``'S/```',P``@,\```<T``"$SP``!S4``(C/
M```'-@``C,\```<W``"0SP``!S@``)3/```'.0``F,\```<[``"<SP``!ST`
M`*#/```'/@``I,\```<_``"HSP``!T```*S/```'0@``L,\```=$``"TSP``
M!T4``+C/```'1@``O,\```='``#`SP``!T@``,3/```'20``R,\```=*``!3
M@^P(Z(<&``"!PP>]``"+@Q0!``"%P'0%Z.H#``"#Q`A;PP``````````````
M``#_LP0```#_HP@`````````_Z,,````:`````#IX/____^C$````&@(````
MZ=#_____HQ0```!H$````.G`_____Z,8````:!@```#IL/____^C'````&@@
M````Z:#_____HR````!H*````.F0_____Z,D````:#````#I@/____^C*```
M`&@X````Z7#_____HRP```!H0````.E@_____Z,P````:$@```#I4/____^C
M-````&A0````Z4#_____HS@```!H6````.DP_____Z,\````:&````#I(/__
M__^C0````&AH````Z1#_____HT0```!H<````.D`_____Z-(````:'@```#I
M\/[___^C3````&B`````Z>#^____HU````!HB````.G0_O___Z-4````:)``
M``#IP/[___^C6````&B8````Z;#^____HUP```!HH````.F@_O___Z-@````
M:*@```#ID/[___^C9````&BP````Z8#^____HV@```!HN````.EP_O___Z-L
M````:,````#I8/[___^C<````&C(````Z5#^____HW0```!HT````.E`_O__
M_Z-X````:-@```#I,/[___^C?````&C@````Z2#^____HX````!HZ````.D0
M_O___Z.$````:/````#I`/[___^CB````&CX````Z?#]____HXP```!H``$`
M`.G@_?___Z.0````:`@!``#IT/W___^CE````&@0`0``Z<#]____HY@```!H
M&`$``.FP_?___Z.<````:"`!``#IH/W___^CH````&@H`0``Z9#]____HZ0`
M``!H,`$``.F`_?___Z.H````:#@!``#I</W___^CK````&A``0``Z6#]____
MH[````!H2`$``.E0_?___Z.T````:%`!``#I0/W___^CN````&A8`0``Z3#]
M____H[P```!H8`$``.D@_?___Z/`````:&@!``#I$/W___^CQ````&AP`0``
MZ0#]____H\@```!H>`$``.GP_/___Z/,````:(`!``#IX/S___^CT````&B(
M`0``Z=#\____H]0```!HD`$``.G`_/___Z/8````:)@!``#IL/S___^CW```
M`&B@`0``Z:#\____H^````!HJ`$``.F0_/___Z/D````:+`!``#I@/S___^C
MZ````&BX`0``Z7#\____H^P```!HP`$``.E@_/___Z/P````:,@!``#I4/S_
M__^C]````&C0`0``Z4#\____H_@```!HV`$``.DP_/___Z,0`0``9I#_HQ0!
M``!FD(U,)`2#Y/#_<?Q5B>575E-1B<_H:`(``('#Z+@``(/L+(M!!(E%U(M!
M"(E%T&6A%````(E%Y#'`C4704(U%U%!1Z+K]__^+@QP!``"#Q`Q04/^S)`$`
M`.B$2@``BX,,`0``@\00@#@`#X0B`0``B[,(`0``@^P,_S;H$O___X"(_@(`
M``):_S;H`____X"(_@(```&+!X/$$(/`!3W___\_#X=5`0``@^P,P>`"4.C=
M_/__BW74BP^#Q!")@W01``#'@W@1```$````BQ:#^0&)$(V3C93__XE0!(N3
M/`$``(E0"(V3D)3__XE0#'X7N@$```"-="8`BSR6B7R0#(/"`3G1=?*#[`S'
M1(@,`````(/!`VH`4(V#4'G__U%0_[.`$0``Z+;]__^#Q""%P(G&#X2M````
M@^P,_[.`$0``C7W@Z,C[__^-@U^3__^)^N@+*@``@\00A<!T;8/L#/^S@!$`
M`.AF^___Z$']__^#Q!")\(M-Y&4S#10````/A:D```"-9?!96UY?78UA_,/H
MN_O__X7`B8.`$0``#X2/````@^P,4.@4^___B[,(`0``6?\VZ-;]__^#Q!#&
M@'$%````Z:O^__^+@WP1``"%P'0]@^P,4.B$2```@\00Z7C___^#[`S_LX`1
M``#H3OW__X/$$(G&Z3O___]04(V##Y/___^S&`$``%#H0/S__XV#%)/__XGZ
MZ$,I``"%P(F#?!$```^$,?___^NFZ%Y)``"#[`QJ`>BD^___,>U>B>&#Y/!0
M5%+H(@```('#M+8``(V#@)+__U"-@R"2__]045;_LR`!``#HL_O___2+'"3#
M9I!FD&:09I!FD&:09I"+'"3#9I!FD&:09I!FD&:0Z.0```"!PFNV``"-BD`!
M``"-@D`!```YR'0=BX+\````A<!T$U6)Y8/L%%'_T(/$$,G#D(UT)@#SPXVV
M`````.BD````@<(KM@``58V*0`$``(V"0`$``"G(B>53P?@"B<.#[`3!ZQ\!
MV-'X=!2+DB@!``"%TG0*@^P(4%'_TH/$$(M=_,G#B?:-O"<`````58GE4^A7
M____@</7M0``@^P$@+M0`0```'4GBX,0`0``A<!T$8/L#/^S-`$``.B=_/__
M@\00Z#7____&@U`!```!BUW\R<.)]HV\)P````!5B>5=Z5?___^+%"3#9I"0
M55>-:#A64X'L#`,``(U,)'B)1"14B70D$&6+'10```")G"3\`@``,=N)3"0(
MB7PD%(VT)@````"+5)T`BT2=!,=$V00`````QT39#`````#'1"0$``````_*
MB00DB139B<+!Z!C!Z@B!X@#_```)T(L4)(G'BP0DP>(8P>`("=<E``#_``GX
MB439"(/#`H/[$'6EBT0D"(V4)'@"``")%"2)Q9"-="8`BU5HBT5L@\4(,U4X
M,T4\,U4(,T4,,U7X,T7\QT5\`````(G'B=")T0^L^!\!T0G!B4UX.RPD=<B+
M7"14BU,,BTL<BS.+>P2+0PB)5"0<BU,4B4PD#(M+)(E$)!B+0Q")5"0$BU,8
MB4PD7(E\)!2)!"2)5"0(BU,@BUPD!(E4)%B)\L'F!8G1B?6+="18#ZSY&XM\
M)`B)5"00"<T#="1XB>B)\8MT)`R!P9EY@EH!R(L,)#'>(W0D'#'/BTPD&(ET
M)"`ASXG^BWPD"#'^`?")1"0@BWPD&(ML)!R+!"2+5"0$QT0D)`````")^8G^
MQT0D/``````/K.X"P>$>B<>+1"00B<V+3"0(QT0D+``````)]0.,)(````")
MUHEL)#");"0XQT0D1`````"!P9EY@EHC="04,>\AQXET)"B)_HL\)#'^BWPD
M)`'QBW0D((G]B?")]\'@!8E$)"B+="0H#ZSO&XML)!0)_HM\)!")\(LT)`'(
MB40D*(GYB?@/K.@"P>$>BWPD!(G-BTPD,`G%`[0DB````!.\)(P```");"1`
MB?"+="0@!9EY@EJ)^HM\)#B#T@`QZ3';(<['1"1,`````,=$)#P`````,?>)
M_HG?BUPD.`'&BT0D*!'7BU0D+(ET)#")?"0TBWPD)(G&QT0D-``````/K-`;
MP>8%BU0D+(G!"?&+="0@B<@#1"0PB?$/K/X"P>$>B40D,(M\)#`)\0.<))``
M``")3"1@B4PD2(G8!9EY@EHQS2-L)"@S;"1`B>F+;"0T`<&)^,'@!8E$)""+
M="0@#ZSO&PG^B?`!R#'_B<:+1"0HB<'!X1X/K-`"B<V+5"1`BTPD8`G%`Y0D
MF````(EL)#B);"1`B=`%F7F"6C'I(TPD,(ML)$B+5"0TQT0D)`````#'1"0T
M`````,=$)$0`````,<V)Z0'!B?#!X`6)1"0@B?"+;"0@#ZSX&XE$)"@+;"0H
MB>B+;"1``<B)1"0@BT0D,(G!#ZS0`L'A'HM4)$P)P8M$)$@#A"2@````$Y0D
MI````(E,)#")3"1(!9EY@EJ#T@`QS3';(?4S;"0XB>D!P8M$)"`1TXM4)"2)
M3"0HB5PD+,=$)"P`````B<'!X06)3"1`B=&+;"1`B<(/K,H;B?$)U8GH`T0D
M*,'A'@^L_@*)S0GUB40D*(EL)$"+7"0X`YPDJ````(MT)#P3M"2L````BTPD
M2(G8B?*+="0@!9EY@EJ#T@`QZ3';B=\ASC-T)#`!QHM$)"@1UXM4)"R)="0X
MB7PD/,=$)#P`````B<8/K-`;P>8%BU0D),=$)"0`````B<$)\8G(`T0D.#'_
MB<:+1"0@B<$/K-`"P>$>BU0D+`G!BT0D,`.$)+````")3"0XB4PD2`69>8):
M,<TC;"0H,VPD0(GI`<&)\,'@!8E$)"")\(ML)"`/K/@;B40D,`ML)#")Z`'(
MB40D((M$)"B)P<'A'@^LT`*)S0G%B6PD,(M4)$`#E"2X````BTPD1!.,)+P`
M``#'1"0T`````,=$)$0`````B=`%F7F"6HG*BTPD2(/2`(E$)"@QVXE4)"R+
M5"0X,>DA\3'*B=`#1"0HB=H35"0LB40D*(M$)"")5"0LBU0D),=$)"P`````
MB<'!X06)3"1`B=&)P@^LRAN+3"1`B50D2`M,)$B)R`-$)"B)\0^L_@+!X1X)
M\8E$)"B+1"0X`X0DP````(E,)$")3"1(!9EY@EHQS2-L)"`S;"0PBWPD*(M4
M)"3'1"0\`````,=$)"0`````QT0D-`````")Z8ML)"P!P8GXP>`%B40D.(MT
M)#@/K.\;"?Z)\`'(,?^)QHM$)"")P<'A'@^LT`*)S8M4)#"+3"1("<4#E"3(
M````B6PD.(EL)$B)T(M4)"P%F7F"6C'I(TPD*(ML)$`QS8GI`<&)\,'@!8E$
M)"")\(ML)"`/K/@;B40D,`ML)#")Z`'(B40D((M$)"B)P0^LT`+!X1Z+5"1$
M"<&+1"1``X0DT````!.4)-0```")3"0PB4PD8(ML)$C'1"1$``````69>8):
M@](`,<TQVR'U,VPD.(GI`<&+1"0@$=.+5"0DB4PD*(E<)"R+7"0XB<''1"0L
M`````,'A!8E,)$")T8ML)$")P@^LRAN)\0G5B>@#1"0HP>$>#ZS^`HG-BTPD
M8`GU`YPDV````(MT)#P3M"3<````B40D*(EL)$")V(GRBW0D(`69>8):@](`
M,>DQVXG?(<XS="0P`<:+1"0H$=>+5"0LB70D.(E\)#S'1"0\`````(G&#ZS0
M&\'F!8M4)"2)P0GQB<@#1"0X,?^)QHM$)"")P0^LT`+!X1X)P8E,)#B+1"0P
M`X0DX````(E,)$B+5"0LQT0D)`````#'1"0T``````69>8):,<TC;"0H,VPD
M0(GI`<&)\,'@!8E$)"")\(ML)"`/K/@;B40D,`ML)#")Z`'(B40D((M$)"B)
MP<'A'@^LT`*)S8M4)$"+3"1$"<4#E"3H````$XPD[````(EL)#")T`69>8):
MB<J+3"1(@](`B40D*#';B50D+(M4)#@QZ2'Q,<J)T`-$)"B)VA-4)"R)1"0H
MBT0D((E4)"R+5"0DB<'!X06)3"1`B=&)P@^LRAN+3"1`BUPD.(E4)$@+3"1(
MQT0D+`````"+5"0DQT0D1`````#'1"0\`````(G(B?$#1"0H#ZS^`L'A'@GQ
M`YPD\````(E$)"B+?"0HB4PD2(E,)$")V`69>8):,<TC;"0@,VPD,(GIBVPD
M+`'!B?C!X`6)1"0XBW0D.`^L[QL)_HGP`<@Q_XG&BT0D((G!P>$>#ZS0`HG-
MBU0D,(M,)$@)Q0.4)/@```");"0XB6PD2(G0!9EY@EHQZ2-,)"B+;"1`,<V)
MZ0'!B?#!X`6)1"0@B?`/K/@;B40D,(ML)"`+;"0PBU0D+,=$)"0`````QT0D
M-`````")Z(ML)$@!R(E$)""+1"0HB<$/K-`"P>$>BU0D1,=$)$0`````"<&+
M1"1``X0D``$``!.4)`0!``")3"1@B4PD,`69>8):@](`,<TQVR'U,VPD.(GI
M`<&+1"0@$=.+5"0DB4PD*(E<)"R+7"0XB<''1"0L`````,'A!8E,)$")T8ML
M)$")P@^LRAN+3"1@"=6)\HGH`T0D*,'B'@^L_@*)U0GU`YPD"`$``(E$)"B)
M;"1`B6PD8(MT)""+5"0LB=@%F7F"6C'I(<XS="0PB?$!P8M$)"B)Q@^LT!O!
MY@6+5"0DQT0D)`````")1"0XBVPD.(M$)"`)]0'I,?^+;"1@B<Z)3"1(B<'!
MX1X/K-`"B<N+5"0P"<,#E"00`0``B5PD,(G0BU0D1`69>8):,=TC;"0H,VPD
M0(M<)"R)Z0'!B?#!X`6)1"0@B?"+;"0@#ZSX&XE$)#@+;"0X`>F)3"1@B4PD
M((M,)"B)R,'@'@^LV0*)Q8M$)$`)S0.$)!@!``"+3"0P$Y0D'`$``(EL)#@%
MH>O9;H/2`#'IBVPD2#';QT0D-``````QS8GI`<&+1"0@$=.+5"0DB4PD*(E<
M)"R)\\=$)"P`````B<'!X06)3"1`B=&+;"1`B<(/K,H;BTPD*`G5B?(!Z<'B
M'HG5BY0D(`$``(E,)$@/K/L"B4PD*(M,)#`)W8'"H>O9;HM<)"R)T(EL)$"+
M5"0D`<@S;"0XB>F+;"1@,<V+3"0HB>X!QHG(P>`%B40D,(M$)""+;"0P#ZS9
M&XGS"<V)P0'KP>$>#ZS0`HG-BY0D*`$``(E<)#`)Q8M$)#B)7"1@B>^+;"1`
M@<*AZ]ENB7PD.`'0,?V+?"0PB>Z+;"1(,?6)Z8ML)#0!P8GXP>`%B40D((MT
M)"`/K.\;BT0D*(M4)"P)_L=$)"0`````QT0D+``````!\8E,)$B)3"0@B<'!
MX1X/K-`"B<V+C"0P`0``BU0D)`G%BT0D0(GNBVPD.('!H>O9;HET)$`!R#'U
MB>Z+;"1@,?6)Z0'!BT0D((G&#ZS0&\'F!8M4)#2)1"0HBVPD*(M$)#`)]0'I
M,?^)SHE,)&")P<'A'@^LT`*)RXN4)#@!```)PXM$)#B)W8E<)#B+7"1`@<*A
MZ]EN`="+5"0D,>N+;"1(,=V)Z0'!B?#!X`6)1"0HB?"+;"0H#ZSX&XE$)#`+
M;"0PBT0D(`'IB4PD2(E,)"B)P<'A'@^LT`*)S0G%B6PD,(N4)$`!``"+C"1$
M`0``BT0D0(ML)#B!PJ'KV6Z#T0")RXG1,=(!R!':,VPD,(E$)"")5"0DBU0D
M8#';B=F+1"0HBYPD2`$``#'J`U0D(!-,)"2)5"0@BU0D+(E,)"2)P<=$)"0`
M````P>$%B4PD0(G1BVPD0(G"BT0D.`^LRAN+3"0@"=6+5"0D`>F)3"0@B4PD
M8(GQP>$>#ZS^`HG-"?6!PZ'KV6Z)[XML)#`!V(E\)#@Q_8GNBVPD2#'UB>D!
MP8M$)"")RXG&#ZS0&\'F!8E$)$"+;"1`BT0D*`GU`>N)P3'_B5PD2(M4)"S!
MX1Z)WL=$)"P`````#ZS0`HN4)%`!```)P8M$)#")S8M,)#B!PJ'KV6Z);"1`
M`="+5"0D,>F+;"1@,<V)Z0'!B=C!X`6)1"0HB=B+;"0H#ZSX&XE$)#`+;"0P
MBT0D(`'IB4PD*(E,)&")P<'A'@^LT`*+E"18`0``B<V+C"1<`0``"<6+1"0X
MB6PD,(ML)$"!PJ'KV6Z#T0")RXG1,=(!R!':,VPD,(E$)"")5"0DBU0D2#';
MB=F+1"0H,>H#5"0@$TPD)(E4)""+5"0LB4PD)(G!P>$%B4PD.(G1BVPD.(G"
MBYPD8`$``(M$)$`/K,H;BTPD(,=$)"0`````"=6+5"0D`>F)3"1(B4PD((GQ
MP>$>#ZS^`HG-"?6!PZ'KV6Z)[XML)#`!V(E\)#@Q_8GNBVPD8#'UB>D!P8M$
M)"")Q@^LT!O!Y@6+5"0LQT0D+`````")1"1`BVPD0(M$)"@)]0'I,?^)SHE,
M)&")P<'A'@^LT`*)RXN4)&@!```)PXM$)#")W8E<)$"+7"0X@<*AZ]EN`="+
M5"0D,>N+;"1(,=V)Z0'!B?#!X`6)1"0HB?"+;"0H#ZSX&XE$)#`+;"0PBT0D
M(`'IB4PD2(E,)"B)P<'A'@^LT`*)S0G%B6PD,(N4)'`!``"+C"1T`0``BT0D
M.(ML)$"!PJ'KV6Z#T0")RXG1,=(!R!':,VPD,(E$)"")5"0DBU0D8#';B=F+
M1"0HBYPD>`$``#'J`U0D(!-,)"2)5"0@BU0D+(E,)"2)P<=$)"0`````P>$%
MB4PD.(G1BVPD.(G"BT0D0`^LRAN+3"0@"=6+5"0D`>F)3"0@B4PD8(GQP>$>
M#ZS^`HG-"?6!PZ'KV6Z)[XML)#`!V(E\)#@Q_8GNBVPD2#'UB>D!P8M$)"")
MRXG&#ZS0&\'F!8E$)$"+;"1`BT0D*`GU`>N)P3'_B5PD2(M4)"S!X1Z)WL=$
M)"P`````#ZS0`HN4)(`!```)P8M$)#")S8M,)#B!PJ'KV6Z);"1``="+5"0D
M,>F+;"1@,<V)Z0'!B=C!X`6)1"0HB=B+;"0H#ZSX&XE$)#`+;"0PBT0D(`'I
MB4PD*(E,)&")P<'A'@^LT`*+E"2(`0``B<V+C"2,`0``"<6+1"0XB6PD,(ML
M)$"!PJ'KV6Z#T0")RXG1,=(!R!':,VPD,(E$)"")5"0DBU0D2#';B=F+1"0H
M,>H#5"0@$TPD)(E4)""+5"0LB4PD)(G!P>$%B4PD.(G1BVPD.(G"BYPDD`$`
M`(M$)$`/K,H;BTPD(,=$)"0`````"=6+5"0D`>F)3"0@B4PD.(GQP>$>#ZS^
M`HG-"?6!PZ'KV6Z)[XML)#`!V(E\)$`Q_8GNBVPD8#'UB>D!P8M$)"")Q@^L
MT!O!Y@6+5"0LQT0D+`````")1"1(BVPD2(M$)"@)]0'I,?^)SHE,)&")P<'A
M'@^LT`*+E"28`0``B<N+C"2<`0``"<.+1"0PB=V!PJ'KV6Z);"1(@]$`B<N)
MT3'2`<@1VHM<)$`QZXML)#@QW3';B>D!P8GP$=/!X`4QTHE$)"B)\(ML)"@/
MK/@;B40D,`ML)#"+1"0@`>D1TXG*B<&)7"1LB50D:,'A'HE4)"B+5"0DB<V+
MC"2D`0``QT0D-``````/K-`"BY0DH`$```G%BT0D0(EL)#B+;"1(@<*AZ]EN
M@]$`B<N)T3'2`<@1VC-L)#B)1"0@B50D)(M4)&`QVXG9BT0D*(N<)*@!```Q
MZ@-4)"`33"0DB50D((M4)"R)3"0DB<'!X06)3"0PB=&+;"0PB<*+1"1(#ZS*
M&XM,)"`)U0'IB4PD,(E,)$")\<'A'@^L_@*)S8M\)#`)]8'#H>O9;@'8BUPD
M.(EL)&`QZXML)&@QW8GIBVPD-`'!B?C!X`6)1"0@BW0D(`^L[QL)_HGP`<B)
M1"0@BT0D*(M4)"R+="1@BWPD0,=$)"0`````B<''1"0L`````,=$)$P`````
M#ZS0`L'A'HN4)+`!``")\XG-QT0D/``````)Q8M$)#B!PJ'KV6Z);"1(`=`Q
MZXM4)"0QWXN<)+P!``")^0'!BT0D(,'@!8E$)"B+1"0@BWPD*`^LT!N+5"0T
MB40D.`M\)#B)^`'(B40D*(M$)#")P0^LT`+!X1X)P8GPB<^)3"0XBXPDN`$`
M`('!W+P;CX/3`#'2`<B+3"1($=H)_2-L)"`QVR'YB<X)[HGQ`<&+1"0H$=.+
M5"0LB4PD,(E<)#2)P<'A!8E,)$")T8ML)$")P@^LRAL)U8GH`T0D,(M4)"0Q
MVXMT)$C'1"0T`````,=$)$0`````B40D,(M$)"")P<'A'@^LT`*)S8GYB?H)
MQ8M$)"@)Z2'JB6PD0"'(B<<)UP.T),`!``")^8M\)$P3O"3$`0``QT0D3```
M``")\(G.!=R\&X^)^HG?@](``<:+1"0P$=>+5"0TB70D((E\)"2)Q@^LT!O!
MY@6+5"0LB<$)\8G(`T0D(#'_B<:+1"0HB<$/K-`"P>$>"<&+1"0XB<H)S8E,
M)$@C;"0PB4PD8(M,)$`AT0G-`X0DR`$``(GI!=R\&X\!P8GPP>`%B40D((GP
M#ZSX&XE$)"B+;"0@"VPD*(M4)#3'1"0D`````,=$)#0`````QT0D/`````")
MZ`'(,=N)1"0@BT0D,(G!P>$>#ZS0`HM4)&")S0G%B6PD,`GJB="+5"1((?`A
MZ@G0BU0D1(G!BT0D0`.$)-`!```3E"34`0``!=R\&X^#T@`!P8M$)"`1TXM4
M)"2)3"0HB5PD+,=$)"P`````B<'!X06)3"0XB=&)P@^LRAN+3"0XB50D0`M,
M)$")R`-$)"B)\<'A'HE$)"B)\`^L^`*+?"0P"<$)S2-L)"")3"0X(<^)3"1@
MBW0D2(M4)"3'1"1$``````G]`[0DV`$``(M\)"B)Z8ML)"R)\`7<O!N/`<&)
M^,'@!8E$)$"+="1`#ZSO&PG^B?`!R#'_,=N)QHM$)"")P<'A'@^LT`*)S8M4
M)&`)Q8M$)"B);"1`">HAT(M4)#@AZ@G0BU0D-,=$)#0`````B<&+1"0P`X0D
MX`$``!.4).0!```%W+P;CX/2``'!B?`1T\'@!8E,)"")P8GPBU0D+`^L^!N)
M7"0DQT0D)`````")1"0P"TPD,(G(`T0D(#';B40D((M$)"B)P0^LT`+!X1X)
MP8G*"<V)3"0PB4PD2(M,)$`A]8M$)#@AT8M4)#S'1"0\``````G-`X0DZ`$`
M`!.4).P!``")Z07<O!N/@](``<&+1"0@$=.+5"0DB4PD*(E<)"S'1"0L````
M`(G!P>$%B4PD.(G1BVPD.(G"#ZS*&XGQ"=6+5"1(B>@#1"0HP>$>B<TQVXE$
M)"B)\(MT)$`/K/@""<6+1"0@">J);"0X(="+5"0PB<<AZ@G7`[0D\`$``(GY
MBWPD1!.\)/0!``")\(G.!=R\&X^)^HG?@](``<:+1"0H$=>+5"0LB70D0(E\
M)$2)Q@^LT!O!Y@6)P0GQB<@#1"1`,?^)QHM$)""+5"0DQT0D)`````#'1"1$
M`````,=$)#0`````B<$/K-`"P>$>"<&+1"0PB<J)3"1`B4PD2`G-BTPD."-L
M)"@AT8M4)"P)S0.$)/@!``")Z07<O!N/`<&)\,'@!8E$)"")\(ML)"`/K/@;
MB40D,`ML)#")Z`'(,=N)1"0@BT0D*(G!P>$>#ZS0`HM4)$B)S0G%B6PD,`GJ
MB="+5"1`(?`AZ@G0BU0D/(G!BT0D.`.$)``"```3E"0$`@``!=R\&X^#T@`!
MP8M$)"`1TXM4)"2)3"0HB5PD+(G!P>$%B4PD.(G1B<(/K,H;B50D2(M,)#@+
M3"1(QT0D+`````"+5"0DQT0D/`````#'1"1$`````(G(`T0D*(GQP>$>B40D
M*(GPBW0D0`^L^`*+?"0P"<$)S2-L)"")3"0X(<^)3"1("?T#M"0(`@``BWPD
M*(GIBVPD+(GP!=R\&X\!P8GXP>`%B40D0(MT)$`/K.\;"?Z)\`'(,?\QVXG&
MBT0D((G!P>$>#ZS0`HG-BU0D2`G%BT0D*(EL)$`)ZB'0BU0D."'J"="+5"0T
MB<&+1"0P`X0D$`(``!.4)!0"```%W+P;CX/2``'!B?`1T\'@!8E,)"")P8GP
MB5PD)`^L^!N)1"0P"TPD,(M4)"S'1"0D`````,=$)#0`````B<@#1"0@,=N)
M1"0@BT0D*(G!#ZS0`L'A'@G!BT0D.(G*B4PD,(E,)$@)S8M,)$`A]2'1BU0D
M/,=$)#P`````"<T#A"08`@``$Y0D'`(``(GI!=R\&X^#T@`!P8M$)"`1TXM4
M)"2)3"0HB5PD+,=$)"P`````B<'!X06)3"0XB=&+;"0XB<(/K,H;B?$)U8M4
M)$B)Z`-$)"C!X1Z)S3';B40D*(GPBW0D0`^L^`()Q8M$)"`)ZHEL)#@AT(M4
M)#")QR'J"=>)^8M\)$0#M"0@`@``$[PD)`(``,=$)#0`````B?")S@7<O!N/
MB?J)WX/2``'&BT0D*!'7BU0D+(ET)$")?"1$QT0D1`````")Q@^LT!O!Y@6+
M5"0DQT0D)`````")P0GQB<@#1"1`,?^)QHM$)"")P0^LT`+!X1X)P8M$)#")
MRHE,)$")3"1("<V+3"0X(VPD*"'1BU0D+`G-`X0D*`(``(GI!=R\&X\!P8GP
MP>`%B40D((GPBVPD(`^L^!N)1"0P"VPD,(GH`<@QVXE$)""+1"0HB<'!X1X/
MK-`"BU0D2(G-"<6);"0P">J)T(M4)$`A\"'J"=")P8M$)#@#A"0P`@``BU0D
M/!.4)#0"``#'1"0\``````7<O!N/@](``<&+1"0@$=.+5"0DB4PD*(E<)"S'
M1"0L`````(G!P>$%B4PD.(G1B<(/K,H;BTPD.(E4)$@+3"1(BU0D)(G(`T0D
M*(GQP>$>B40D*(GPBW0D0`^L^`*+?"0P"<$)S2-L)"")3"0X(<^)3"1("?T#
MM"0X`@``BWPD*(GIBVPD+(GP!=R\&X\!P8GXP>`%B40D0(MT)$`/K.\;"?Z)
M\`'(,?\QVXG&BT0D((G!P>$>#ZS0`HG-"<6);"1`QT0D1`````"+5"1(BT0D
M*`GJ(="+5"0X(>H)T(M4)#2)P8M$)#`#A"1``@``$Y0D1`(```7<O!N/@](`
M`<&)\!'3P>`%B4PD((G!B?"+5"0L#ZSX&XE<)"3'1"0D`````(E$)#`+3"0P
MQT0D+`````")R`-$)"`QVXE$)""+1"0HB<$/K-`"P>$>"<&+1"0XB<H)S8E,
M)"B)3"1@BTPD0"'U(=&+5"0\"<T#A"1(`@``$Y0D3`(``(GI!=R\&X^#T@`!
MP8M$)"`1TXM4)"2)3"0PB5PD-(G!P>$%B4PD.(G1BVPD.(G"B?#'1"0T````
M``^LRAN+3"0PQT0D/``````)U8M4)&`!Z8E,)$B)3"0PB?$/K/@"P>$>BW0D
M0(G-"<6+1"0@">J);"1HB6PD."'0BU0D*(G'(>H)UP.T)%`"``"+5"0TB?F)
M\`7<O!N/`<&+1"0PB<N)Q@^LT!N+5"0DP>8%B40D0(ML)$"+1"0@"?4!ZXG!
M,?\/K-`"P>$>BU0D+(ML)&@)P8M$)"@#A"18`@``$Y0D7`(``(E<)&")WHE,
M)$`%UL%BRH/2`#'-B40D((E4)"2+5"1(B=@QZHG1`TPD(,'@!8E$)"")V(ML
M)"`/K/@;BU0D-(M<)$")1"0H"VPD*(M$)##'1"0D``````'IB4PD((E,)$B)
MP<'A'@^LT`*)S8M4)#P)Q8M$)#@#A"1@`@``$Y0D9`(``(EL)#@%UL%BRH/2
M`#'KBVPD8#'=,=N)Z0'!BT0D(!'3BU0D)(E,)"B)7"0LB?/'1"0L`````(G!
MP>$%B4PD,(G1BVPD,(G"#ZS*&XM,)"@)U8GR`>G!XAZ)U8N4)&@"``")3"1@
M#ZS[`HE,)"B+3"1`"=V!PM;!8LJ)T(EL)$`!R#-L)#B)Z8ML)$B+7"0LBU0D
M),=$)#0`````QT0D)``````QS8M,)"B)[@'&B<C!X`6)1"0PBT0D((ML)#`/
MK-D;B?.+="1`"<V)P0'KP>$>#ZS0`HG-BY0D<`(``(E<)#`)Q8M$)#B+?"0P
MB6PD.(E<)$B!PM;!8LH!T#'NBVPD8(M4)"PQ]8GIBVPD-`'!B?C!X`6)1"0@
MBW0D(`^L[QN+1"0H"?X!\8MT)#B)3"0@B4PD8(G!P>$>#ZS0`HG-BXPD>`(`
M`(M4)"0)Q8M$)$")[XGU@<'6P6+*B7PD.`'(,?TS;"1(B>D!P8M$)"#!X`6)
MQXM$)"`/K-`;B40D*(ML)"B+1"0PBU0D-,=$)"P`````QT0D-``````)_0'I
MB4PD2(E,)"B)P0^LT`*+E"2``@``P>$>B<T)Q8GP@<+6P6+*B6PD0`'0,VPD
M.(M4)"PS;"1@B>D!P8M$)"B)RXG&B<>+1"0XP>8%B70D,(ML)#`/K-<;"?V+
M?"0@`>N+;"0DQT0D)`````")7"0PB5PD8(GZB?Z+?"0T#ZSN`L'B'HG5BY0D
MB`(```GUBW0D0(EL)#B!PM;!8LH!T#'NBVPD2#'UBW0D,(GIB?T!P8GPB??!
MX`6)1"0@BW0D(`^L[QN+1"0H"?X!\8E,)$B)3"0@B<&+5"0LP>$>BWPD.(G-
MQT0D+``````/K-`"BY0DD`(```G%BT0D0(GNB?V!PM;!8LJ)="0X`=`Q]3-L
M)&"+5"0DB>D!P8M$)"")R\'@!8E$)"B+1"0@BVPD*`^LT!N+5"0TQT0D-```
M``")1"1`"VPD0(M$)#`!ZXG!#ZS0`HN4))@"``#!X1Z)7"0HB<V)7"1@"<6)
M^('"UL%BRHEL)$`!T#-L)#B+5"0L,VPD2(GI`<&+1"0HB<:)Q\'F!8ET)#"+
M;"0P#ZS7&PG]BWPD(`'IBVPD)(E,)$B)3"0PB?J)_@^L[@+!XAZ)U8N4)*`"
M``"+1"0X"?6+="1`BWPD-(EL)#C'1"0D`````('"UL%BR@'0,>Z+;"1@BU0D
M+,=$)"P`````,?6+="0PB>F)_0'!B?")]XG+P>`%B40D((M$)"B+="0@#ZSO
M&XG!"?Z+?"0X`?/!X1X/K-`"B<V+E"2H`@``B5PD(`G%BT0D0(E<)&")[HG]
M@<+6P6+*B70D:`'0,?4S;"1(BU0D)(GI`<&+1"0@P>`%B40D*(M$)""+;"0H
M#ZS0&XM4)#2)1"0X"VPD.(M$)#`!Z8E,)$")3"0HB<$/K-`"BY0DL`(``,'A
M'HG-"<6)^('"UL%BRHEL)#@!T#'U,VPD8(M4)"S'1"0T`````(GI`<&+1"0H
MB<N)QHG'BT0D:,'F!8ET)#"+;"0P#ZS7&PG]BWPD(`'KBVPD),=$)"0`````
MB5PD,(E<)$B)^HG^BWPD-`^L[@+!XAZ)U8N4)+@"```)]8MT)#B);"1H@<+6
MP6+*`=`Q[HML)$"+5"0L,?6+="0PB>F)_0'!B?")]\'@!8E$)""+="0@#ZSO
M&XM$)"@)_HM\)&@!\8E,)"")3"1@B<'!X1X/K-`"B<V+E"3``@``"<6+1"0X
MB>Z)_8'"UL%BRHET)#@!T#'U,VPD2(GI`<&+1"0@B<O!X`6)1"0HBT0D((M4
M)"2+;"0HQT0D+``````/K-`;BU0D-,=$)#0`````B40D0(M$)#`+;"1`B<$!
MZ\'A'@^LT`*+E"3(`@``B<V+C"3,`@``"<6)7"1(B5PD*(GXB6PD0('"UL%B
MRH/1`(G+B=$QT@'($=HS;"0X,=LS;"1@B>D!P8M$)"@1TXM4)"R)QHG'BT0D
M.,'F!8ET)#"+;"0P#ZS7&S'2"?V+?"0@`>F+;"0D$=.)3"0PB4PD8(GZB?Z+
M?"0T#ZSN`L'B'HE<)&2)U8N4)-`"```)]8MT)$");"0X@<+6P6+*`=`Q[HML
M)$@Q]8MT)#")Z8G]`<&)\(GWB<O!X`6)1"0@BW0D((M$)"B+5"0L#ZSO&\=$
M)"0`````QT0D+``````)_HG!BWPD.`'SP>$>#ZS0`HN4)-@"``")S8N,)-P"
M```)Q8M$)$")7"0@B5PD2(GNB?V!PM;!8LJ#T0")RXG1,=(!R!':,?4S;"1@
M,=N)="1@B>D!P8M$)"`1TXM4)"3!X`6)1"0HBT0D((ML)"@/K-`;,=*)1"0X
M"VPD.(M$)#`!Z1'3BU0D-(E,)"B)3"1`B<&)7"1$P>$>#ZS0`HN4).`"``")
MS8N,).0"```)Q8GXB6PD.('"UL%BRH/1`(G+B=$QT@'($=HQ]3-L)$@QVXGI
M`<&+1"0H$=.+5"0LB<:)Q\'F!8ET)#"+;"0PB=X/K-<;B<LQTHM$)&`)_8M\
M)"#'1"0T``````'KBVPD),=$)"0`````$=:)7"0PB5PD2(ET)$R)^HG^#ZSN
M`L'B'HM\)$")U8N4).@"```)]8MT)#B);"1@@<+6P6+*`=`Q[HM4)"PQ]XMT
M)#")^8M\)#0!P8GPP>`%B?V)]XE$)""+="0@#ZSO&XML)&`)_HGP`<B)1"0@
MBT0D*(G!#ZS0`L'A'HM4)#`)P8M$)#B)SXM,)#2)TXE\)$#!XQZ)SHE<)"@/
MI-8>#ZS*`L'I`HET)"R)[HE,)#2+C"3P`@``B50D,('!UL%BR@'(,?XS="1(
MB?$!P8M$)"#!X`6)QHM$)""+5"0DBUPD*`^LT!O!ZAN)1"0XBWPD.(E4)#P)
M]XGXBWPD5`'(B<&+1"08`TPD$`-$)"`+7"0PQT<$`````,='#`````#'1Q0`
M````QT<<`````(D/QT<D`````(E'"(G8`P0DB4<0BT0D0`-$)`B)1QB)Z`-$
M)%B)1R"+A"3\`@``93,%%````'4+@<0,`P``6UY?7</H,2```)!55U93Z!?7
M__^!PY>-``"#[!R%P`^$G@```(N++`$``(L)A<F)3"0(#X2*````#[8(A,ET
M!8#Y/75&,?:+?"0(BR^%[70OB50D#(E$)`1FD(/L!%;_="0,5>BRT___@\00
MA<!U!X!\-0`]="R#QP2++X7M==N#Q!R)Z%M>7UW#D(G&@\8!#[8.A,ET!8#Y
M/77Q*<;KIXUV`(GZ*U0D"(M$)`R-;#4!P?H"B1"#Q!R)Z%M>7UW#C78`,>WK
MN8UT)@!75HG&4^A/U___@<+6C```@^P0B[HL`0``C5PD"&6A%````(E$)`PQ
MP(G:B?#H#O___X7`=#.+5"0(BP>-!)"+4`2%THD0=.&0C;0F`````(/`!(M0
M!(72B1!U](G:B?#HV_[__X7`=<V+1"0,93,%%````'4'@\006UY?P^CN'@``
MC;0F`````(V\)P````!55XG%5E.)UNC#U?__@<-#C```@^PX9:$4````B40D
M*#'`,<"`.CT/E,`!QE;H+M'__X/$$(D$)(GHC50D&.AM_O__A<`/A`T!``"#
M[`R)QU#H"M'__X/$$#L$)`^#W@```(M$)!B-#(4`````BX,L`0``B40D!`^V
M10"$P`^$I0$``#P]#X2=`0``B>CK!I"`^CUT"H/``0^V$(32=?$IZ(M4)`2#
M[`R+.@'/BTPD#(U$"`)0Z$;0__^#Q!"%P(D'#X1U`0``BU0D!(U-`8L"BU0D
M&(L4D`^V10`\/8@"=".$P'4/ZQV)]HV\)P`````\/700@\$!#[9!_X/"`83`
MB`)U[,8"/3'`C;0F``````^V#`:(3`(!@\`!A,EU\3'`BUPD'&4S'10````/
MA10!``"#Q"Q;7E]=PXVV`````(/&`0^V1O^#QP&$P(A'_W7OZ\R0C70F`(N#
M+`$``(L0B40D!(LZA?\/A,(````QP.L(C;8`````B?B->`&+#+J%R77TC02%
M#````(N+<!$``(7)=6N)5"0(@^P,QX-P$0```0```%#H5,___X/$$(7`#X2%
M````C0R]`````(/L!%&+5"00B4PD%%*)1"044.CKS?__BTPD%(M$)!B#Q!")
M`8M,)`R+1"0(QT2X!`````")?"08Z7S^__^0C70F`(/L"%!2Z.;.__^+3"04
MB40D&(/$$(7`B0%T(8T,O0````#KPHUT)@`QP.ER_O__D+@(````,?_I3___
M_[C_____Z=O^___HE1P``)"-="8`55>)Q593Z'73__^!P_6)``"![(P```!E
MH10```")1"1\,<"%[70&@'T``'4CBT0D?&4S!10````/A2\!``"!Q(P```!;
M7E]=PXVT)@````"#[`Q5Z'?0__^#Q!"%P(G&=,N-@\"2__^_+@```(DL)(E$
M)`2#[`Q6Z-//__^#Q!"%P(G%#X2^````#[9%$XGZ*<*)T'4:#[9%%(7`=-:)
M^2G!B<AU"@^V117WV(UT)@"%P'3`@^P,_W0D#.A0SO__C4T3B40D'(D,)(E,
M)!CH/<[__XM4)!R-1`("B00DZ,W-__^)Q5A:BTPD$%'_="0,_W0D%&K_:@%5
MZ.+/__^#Q!R-1"0@4%5J`^ARS___@\00@_C_=!"+1"0L)0#P```]`$```'0^
M@^P,5>C1S/__@\00@^P,5>A%S/__@\00Z3'___^0C70F`(LL)(/L#%;H;,__
M_XDL).A4S/__@\00Z<G^__^)Z.B5_O__Z\7H'AL``(VT)@````"-O"<`````
M5U:)QU/H]M'__X'#=H@``(/L#(NS"`$``/\VZ/#.__^#Q`P%/`$``%!7:@/H
M[\[__X/$$(7`=`A;,<!>7\-FD(/L#/\VZ,;.__^+@$P!``"#Q!`E`/```#T`
M0```=!^#[`S_-NBGSO__BX!,`0``@\00)0#P```]`*```'6Z@^P(:@)7Z/?-
M__^#Q!"%P`^4P%L/ML!>7\.0C;0F`````%57B<=64^A5T?__@</5AP``@>PP
M$```9:$4````B80D(!```#'`B50D#&C_#P``C8/&DO__C70D)%90Z,#+__^#
MQ!"%P`^.C0```(UH_XN3"`$``(!\+!P`BQ)T4XG%B50D#(/L!%5J+U;H$<W_
M_X/$$(7`BU0D#'0^@^P,4NCMS?__55974.B$S?__@\0@BX0D'!```&4S!10`
M``!U0X'$+!```%M>7UW#C;8`````A>UUJXUT)@"#[`Q2Z*_-__^#Q`S_="0,
M5U#H0<O__X/$$.N[C70F`(N#"`$``(L0Z];HB1D``(GVC;PG`````%/H:M#_
M_X'#ZH8``(/L%(N#"`$``/\PZ&3-__^-D[B4__]2C9/5DO___[,$`0``4E#H
M&LS__X/$*%O#D(UT)@!64^@IT/__@<.IA@``@^P0B[,(`0``_S;H(\W__XD$
M).B;____6/\VZ!/-__]:C9-LE/__66H`4E*-D]"-__]2C9/QDO__4E#H4\S_
M_X/$)%M>PXVV`````(V\)P````!55U93Z,?/__^!PT>&``"![!P@``!EH10`
M``")A"0,(```,<#HI\K__XV3T9+__X/L"%)0C8,&D___4&@!$```:@&-="0F
M5NCDS/__@\0<:``0``"-O"03$```5U;H#LK__X/$$(7`>$>)QHU``8/L#%#H
MB<K__X/$$(7`B<5T$X/L!%974.A5R?__QD0U``"#Q!"+C"0,(```93,-%```
M`(GH=0^!Q!P@``!;7E]=PS'MZ]_H)Q@``(VT)@````#I.____XUT)@"-O"<`
M````55=64^CWSO__@<-WA0``@>P\$```B[PD4!```(U4)"B+M"14$```9:$4
M````B80D+!```#'`C8,4D___B7PD#.B;]___@^P(B<5J+U?H'LK__X/$$(7`
M=#>+?"0,C8,=D___B?KHQOC__XGXBY0D+!```&4S%10````/A:`!``"!Q#P0
M``!;7E]=PY"-="8`@^P,_W0D&.CTR?__6EF)1"0<C8,JD___B40D&%!6Z-W*
M__^#Q!"%P(G&=)V-@Q*3__^`/@")1"0<BX,(`0``B40D&`^$Z````(VT)@``
M``"%[705@^P(5E7HTL?__X/$$(7`#X2D````@^P,5NB.R?__@\00@'P&_R]U
M$HUT)@"#Z`&`?`;_+\8$!@!T\HM,)!2-1`@!/?\/```/CRC___^-@RR3__^#
M[`3_="004(V#)Y3__U90:``0``!J`8UT)$A6Z`C+__^#Q!2+?"0D_S?HJLK_
M_X/$#`4\`0``4%9J`^B)RO__@\00A<!U'X/L#/\WZ(C*__^+@$P!``"#Q!`E
M`/```#T`@```=%.#[`C_="08:@#HY<G__X/$$(7`B<8/A*'^__^`/@`/A1__
M__^%[703BWPD'+D"````B>[SIG3)C70F`(MT)!RX`0```.DX____C78`C;PG
M`````(/L"&H!5NB%R?__@\00A<!UFXV#'9/__XGRZ"'W__^#[`Q6Z.C(__^#
MQ!#I3/[__^CK%0``C70F`(V\)P````"+5"0$#[8*B="$R70;C78`@\(!@/DO
M#[8*#T3"A,EU\//#C;8`````\\.-M@````!64^B9S/__@<,9@P``@^P4BW0D
M((7V=#@/MA:$TG0QB%0D#X/L#%;H!,C__XU$!O^#Q!`/ME0D#SG&<@OK/F:0
M@^@!.<9T.8`X+W3TZR=FD(/L#&H"Z';'__^#Q!"%P'1_NBX```!FB1"#Q!1;
M7L.0@#@O=#"#Z`$YQG+T.<9U)8#Z+W3+C8,LD___@^P,4.@,R/__@\00Z]"-
MM"8`````@#@O=0>#Z`$YQG+T*?"-4`*!^@`0``!W)X/``6@`$```4%:-LW`!
M``!6Z"'(__^#Q!")\(/$%%M>PXVV`````(/$%#'`6U[#D(VT)@````!75E/H
MJ,O__X'#*((``(/L,&6A%````(E$)"PQP(N#E)3__XUT)`2)1"0*BX.8E/__
MB40D#HN#G)3__XE$)!*+@Z"4__^)1"06BX.DE/__B40D&HN#J)3__XE$)!Z+
M@ZR4__^)1"0BBX.PE/__B40D)@^W@[24__]FB40D*HV#+I/__^C(]/__C8,W
MD___Z+WT__^-@S^3___HLO3__XV#2)/__^BG]/__C8-/D___Z)ST__^-@U^3
M___HD?3__XV#%)/__^B&]/__C8-KD___Z'OT__^-@W63___H</3__XV#?Y/_
M_^AE]/__C8,=D___Z%KT__^-@XF3__^)\NB-\___A<!T#8G"C8-UD___Z,ST
M__^-@YJ3__^)\NAO\___A<!T#8G"C8.LD___Z*[T__^-@[>3__^)\NA1\___
MA<!T-8G"C8,4D___Z)#T__^-D^.3__^-@T^3___H?_3__XM$)"QE,P44````
M=5&#Q#!;7E_#C78`C8/'D___B?+H"_/__X7`=2>-="0;C;O8D___N0H```#S
MIG6TC50D)8V#:Y/__^@U]/__ZZ.-=@")PHV#:Y/__^@C]/__ZY'H_!(``(VV
M`````(V_`````%/HVLG__X'#6H```(/L&&6A%````(E$)`PQP(N#.`$``(/X
M_W0:BTPD#&4S#10```!U/H/$&%O#D(VT)@````"-5"0(C8-KD___Z''R__^)
MPC'`A=)T$@^V$H#Z,`^5P3'`A-(/E<`AR(F#.`$``.NUZ'H2``"-=@"-O"<`
M````4^A:R?__@</:?P``@^P(Z+S#__^#[`Q0Z"/#__^#Q!"%P'0,BP"#Q`A;
MPY"-="8`,<#K\HVV`````(V_`````%575E/H%\G__X'#EW\``(/L'&6A%```
M`(E$)`PQP(U4)`B-@^63__^+?"0PZ,_Q__^%P'1K@#@`B<9T9(/L"%=0Z(K"
M__^#Q!"%P'5@@^P,5^A:Q/__B<6)-"3H4,3__XU$!0*)!"3HY,/__XG%C8,J
MD___@\0,5E"-@R>4__]74&K_:@%5Z/7%__^-@^63__^#Q"")ZNBU\O__ZQ"-
M=@"-@^63__^)^NBC\O__BT0D#&4S!10```!U"(/$'%M>7UW#Z&D1``")]HV\
M)P````!55U93Z$?(__^!P\=^``"![#R!``"+A"10@0``C50D/(VS]9/__\=$
M)$@`````QT0D;`````")="1,QT0D5`````")1"00B50D"&6A%````(F$)"R!
M```QP(V#`93__XE$)$"-@Q*3__^)1"1$C8.LD___B40D!(E$)%B-@Z63__^)
M1"1<C8,&E/__B40D8(V#PI/__XE$)&2-@PZ4__^)1"1HC8,2E/__B40D4(V#
M%)/__^AX\/__A<!T"8`X``^%&P0``.@F_O__A<")Q0^$-`0``(/L#%7H`\/_
M_XU$``&)!"3HE\+__XE$)!"#Q!"`?0``="R+-"2-NQN4__^0#[9%`(/L#(/%
M`5!7:O]J`5:#Q@+HE\3__X/$((!]``!UWHU\)%B+1"0$BVPD".L)@\<$BP>%
MP'0WB>KH\.___X7`B<9TZH`X`'3EZ`#U__^%P'3<@^P,5NCSPO__@\00A<")
MQG5'C78`C;PG`````#'_C;8`````BW2\0(7V#X1<`0``@#X`#X13`0``B?"#
MQP'HN?3__X7`=-V#[`Q6Z*S"__^#Q!"%P'3-B<:#[`Q6Z"K"__^#Q!"+#"2+
M.8/!!(V7__[^_O?7(?J!XH"`@(!TZ8G7B40D!(LL),'O$/?"@(````]$UXUY
M`HG0#T3/`-"+1"0$@]D#@^P,*>F-O`$$!```5^AUP?__B40D$(G!C8,@E/__
M55"-@RR3__^)1"0X4(V#)93__U:)SE!J_VH!4>AXP___@\0H:,`!``!6Z/K!
M__^#Q!"#^/]U$.@-PO__BP"#^!$/A40)``"+LP@!``"#[`S_-NCRPO__@\0,
M!3P!``!0_W0D"&H#Z.["__^#Q!"%P(G%=&6#[`S_="0,BT0D(/\PC8,`E?__
M4(N#``$``&H!_S#H@L+__X/$(,=$)`0`````BXPD+($``&4S#10```"+1"0$
M#X6["0``@<0\@0``6UY?7<.-="8`,?;IQO[__XGVC;PG`````(/L#/\VZ&;"
M__^+@$P!``"#Q!`E`/```#T`0```#X5X____@^P,_S;H0\+__XN`5`$``(E$
M)!3HE+___X/$$#E$)`0/A5+___^#[`S_-N@=PO__BX!,`0``@\00)?\!```]
MP`$```^%+____X/L#%?H&\#__XM4)!B)1"04C8/PD___Z+CM__^#Q!"%P`^$
M[0$``(/L#%#HQ,#__UY?4(M$)!S_,.BV]?__B40D&(/$$(7`#X3'`0``@^P,
MBWPD%%?H*L#__X/$$(/X`W8RB7PD"(UT!_R-NRZ4__^Y!0```/.F=1N#^`0/
MA$('``"+?"0(@'P'^R\/A#,'``"-=@#H>_K__X7`=1V#[`AJ`/]T)!3H^;__
M_XE$)""#Q!"%P`^%:@$``(V3XY/__XVS;)3__XV#:Y/__XV[593__^A-[O__
MZ!B___]64(V#1Y3___]T)"C_="0,4&K_:@'_="0@Z%K!__^#Q"")="0(BW0D
M!.LVD(UT)@#H\[___X,X$74]Z-F^__^#Q0&#[`S_="0455#_="0X_W0D'%=J
M_VH!5N@:P?__@\0P@^P(:,`!``!6Z)F___^#Q!"#^/]TN8/L#/]T)`SHE;W_
M_XM\)!2-@Q23__^)^NBT[?__B3PDZ%SZ__^#Q!#IW?W__XUT)@"#[`Q0B40D
M$.A#^O__BT0D$(D$).A7O___B40D%(/$$.FT_?__C78`B?`Q_X7`=!V+5"0(
M@\<!Z!3L__^%P'0%@#@`=2N+1+Q,A<!UXX/L#(VK^I/__VH-Z$.^__^)1"00
M@\00Z:W[__^-M"8`````@^P,4.CWOO__@\00A<!TQ8G%Z6W[__^)]HV\)P``
M``"+1"00BP")1"0(Z2K^__^0:@)J_VKNBWPD'%?HL+W__X/$#&H&C80D-`$`
M`(E$)!!05^AYO/__@\00@+PD+`$```!U#H"\)"T!``!##X0Q!@``:@!J`&H`
M_W0D'.AOO?__QX0D@`````$C16?'A"2$`````````,>$)(@```")J\WOQX0D
MC`````````#'A"20````_MRZF,>$))0`````````QX0DF````'94,A#'A"2<
M`````````,>$)*````#PX=+#QX0DI`````````#'A"2H`````````,>$)*P`
M````````QX0DL`````````#'A"2T`````````,>$)/@`````````@\00C40D
M<(E$)"R-A"2H````B40D)(UT)@"#[`1H`(```/]T)!#_="0<Z'N[__^#Q!"%
MP(G%#X[N`0``B[0DF````(N\))P```")Z)G!X`.);"08B50D'(N,)*0````!
M\(/_`(N4)*````!W!#G&=@:#P@&#T0"+?"0<BW0D&(F$))@```"+A"3H````
MQX0DG``````````/K/X=P>\=`=81SX7`B;0DH````(F\)*0````/A&$!``"Z
M0````"G".=4/3M4#1"0D@^P$4O]T)!")UU#H$;O__XN$)/@````!^(F$)/@`
M``"#Q!"#^$`/A27___^+1"0L*?T#?"0(Z-;!__^-M@````"#_3\/CN@```"#
M[4")Z(EL)"B)_<'H!HUP`8E$)!C!Y@8!_HM\)"R)]HV\)P````"+10"#Q4")
MA"2H````BT7$B80DK````(M%R(F$)+````"+1<R)A"2T````BT70B80DN```
M`(M%U(F$)+P```"+1=B)A"3`````BT7<B80DQ````(M%X(F$),@```"+1>2)
MA"3,````BT7HB80DT````(M%[(F$)-0```"+1?")A"38````BT7TB80DW```
M`(M%^(F$).````"+1?R)A"3D````B?CH]L#__SGU#X5.____BT0D&(GOBVPD
M*,'@!BG%:D155_]T)##H(KO__XFL)/@```"#Q!#I`_[__XUV`(M\)`CIY_[_
M_XVT)@````"#[`S_="0<Z-2\__^+E"2L````BX0DJ````(N\)+````"+K"2T
M````B40D&(E4)!P/K-`#B7PD((EL)"2#X#^-4`'&A`2X````@(/$$(/Z.`^/
M=0(``+@X````,?\IT`-4)"2#^`0/@Z\"``"%P'0+J`+&`@`/A64#``"+?"00
MBVPD%(GX#ZSH&(B$).````")^`^LZ!"+;"0,B(0DX0```(GXBWPD"(BD).(`
M``"(A"3C````B?@/K.@8B(0DY````(GX#ZSH$(B$).4```")^(BD).8```"(
MA"3G````BT0D+.C(O___BW0D<(M\)'2)\HGQ#ZSZ&(BL)/$```"(C"3R````
M#[;"B)0D[P```(GRBW0D>`^L^A"+?"1\B)0D\````(GRB?&(K"3U````B(PD
M]@````^L^AB(E"3S````B?*+M"2`````#ZSZ$(N\)(0```"(E"3T````B?*)
M\8BL)/D```"(C"3Z````#ZSZ&(B4)/<```")\HNT)(@````/K/H0B[PDC```
M`(B4)/@```")\HGQB*PD_0```(B,)/X````/K/H8B)0D^P```(GRB[0DD```
M``^L^A"+O"24````B)0D_````(GRB?&(K"0!`0``B(PD`@$``(V,)`,!```/
MK/H8B4PD$(G-C8PD*P$``(B4)/\```")\HVT)/`````/K/H0B4PD"(V[&Y3_
M_XB4)``!``#I#0```(VT)@`````/M@:#Q@&#[`Q05VK_:@%5@\4"Z-"Z__^#
MQ"`Y;"0(==^-@VR4___&A"0K`0```%"-@SB4____="04_W0D*/]T)`Q0:O]J
M`?]T)"#HF+K__X/$(.F/^?__BT0D$(M0!(72#X3!^/__@^P,4HE4)"#HI+C_
M_X/$$(/X`P^&J/C__XM4)!"-NS.4__^Y!0```(UT`OSSI@]%5"0(B50D".F%
M^/__BTPD)+A``````=$IT'0-,=+&!!$`@\(!.<)R]8M$)"SHP+W__XM\)"2Y
M#@```#'`\ZOI>?W__X/L"%#_="0,BT0D(/\PC8/$E/__Z>/V__^-2@3'`@``
M``#'1`+\`````(/A_"G*`<*#XOR#^@0/@CS]__^#XOPQP(D\`8/`!#G0<O;I
M*/W__X"\)"X!``!!#X7!^?__@+PD+P$``$,/A;/Y__^`O"0P`0``2`^%I?G_
M_X"\)#$!``!%#X67^?__:@)J_VK&BW0D'%;H!;?__X/$#&HIBWPD$%=6Z-6U
M__^-@VR4__]0C8,XE/__5_]T)#C_="0<4&K_:@'_="0PZ$&Y__^#Q##I./C_
M_XGVC;PG`````#'M9HEL`O[IC_S__^C/!```ZPV0D)"0D)"0D)"0D)"055=6
M4^BGN___@<,G<@``@^PXB[L(`0``9:$4````B40D*#'`_S?HE;C__UW_-XG&
MZ(NX__\/ME9HB%!IC40D*(E$)!R)PHV#3Y/__^@_Y/__@\00A<!T"8`X,0^$
MKP(``.B:[___@^P,_S?H4+C__XV39I3__VH+:@%24.AOMO__@\0@A<`/A/X`
M``"+0`R#NW@1```!BR^+0!B)1"0(#X[G````,?;K/8VT)@````"+0@R#[`B-
M5@%0BX-T$0``_S20B50D%.BDM/__@\00A<"+BW@1``!U;XM4)`2-0@&)UCG!
M?F*#[`Q5Z-&W__]J`%;_="0@4.A4M___@\0@A<!T/8L0BR^+0@@E``0@`#T`
M!```=)J)5"0$@^P,5>B=M___:@)J`(M4)!Q24.@^M?__BR^#Q"#I=____XUT
M)@"+BW@1``"++XU!_SGP=3V#^0%^.(GHO@$```"+;"0(ZPF-M"8`````BP>#
M[`R#Q@%0Z$JW__]:6550Z%&T__^#Q!`YLW@1``!_WHLO@^P,5>@KM___C9-K
ME/__:@-J`5)0Z$JU__^#Q""%P(G&=#*+0`R#[`R+*/\WZ`*W__^-DVV4__^#
MQ`Q255#HD;3__XM&#(/$$(LP]D8*0`^%;P$``(/L#/\WZ-6V__^-DXN4__]J
M`VH!4E#H]+3__X/$((7`B<9T-HM4)`R-@QV3___H?.+__X7`B<4/A`(!``"+
M1@R#[`R+,/\WZ).V__^#Q`Q55E#H*+3__X/$$(/L#/\WZ'NV__^-DW*4__^#
MQ`QJ`5)0Z!FU__^)QEC_-^A?MO__C9.'E/__@\0,4E90Z.ZS__]:_S?H1K;_
M_XM4)!S&0&D`C8,4D___Z`/B__^#Q!"%P(G&B8-\$0``=$2#[`AHP`$``%;H
M]K3__XU0`8/$$(/Z`78)@_@1#X6R````BT0D'&4S!10````/A9P```"#Q"Q;
M7E]=PXGVC;PG`````(/L#/^S=!$``.AR\/__@\00A<")QHF#?!$``'6?C8-4
ME?__@^P,4.ATM/__C70F`(!X`0`/A$S]___I0OW__Y"+@W01``"#[`R+*(M&
M#(LP_S?HB;7__XGJB?#H$.?__X/$$.GS_O__D(VT)@````"#[`S_-^AFM?__
M65U64.B-M/__@\00Z7;^___H4`$``%"+@W01``!6_S"-@WB5__]0Z/JS__^-
M=@"-O"<`````5U93BUPD$.AC````@<>4;@``@^P,4^AEZ___#[80@\00B<:$
MTG09B?:-O"<`````@\`!@/HO#[80#T3PA-)U\.C[[?__A=MT&(7`=!2`.P!T
M#XV_()3__[D$````\Z9T!%M>7\.)V%M>7^DQY/__BSPDPV:09I!FD&:09I!F
MD)!3Z)JW__^!PQIN``"#[`B-@S0!``"%P'0?BP!0_W0D'/]T)!S_="0<Z%.R
M__^#Q!A;PXVV`````#'`Z]]FD&:055=64^A7M___@</7;0``@^P,BVPD((VS
MW/[__^BOL/__C8/8_O__*<;!_@*%]G0E,?^-M@````"#[`3_="0L_W0D+%7_
ME+O8_O__@\<!@\00.?YUXX/$#%M>7UW#C78`\\-FD&:09I!FD&:09I!FD%/H
MZK;__X'#:FT``(/L".@\L?__4X/L".C3MO__@<-3;0``@\0(6\,#`````0`"
M`"5S+R5S`"]P<F]C+W-E;&8O97AE`$1Y;F%,;V%D97(Z.F)O;W1?1'EN84QO
M861E<@!);G1E<FYA;',Z.E!!4CHZ0D]/5``O<')O8R\E:2\E<P`N`%!!4E]4
M14U0`%!!4E]04D]'3D%-10`Z`"\`4$523#5,24(`4$523$Q)0@!015),-4]0
M5`!015),24\`4$%27TE.251)04Q)6D5$`%!!4E]34$%73D5$`%!!4E]#3$5!
M3@!005)?1$5"54<`4$%27T-!0TA%`%!!4E]'3$]"04Q?1$5"54<`4$%27T=,
M3T)!3%]435!$25(`4$%27U1-4$1)4@!005)?1TQ/0D%,7U1%35``4$%27T=,
M3T)!3%]#3$5!3@!005)?0TQ%04X]`#$`3$1?3$E"4D%265]0051(`%5315(`
M4UE35$5-`"]T;7``5$5-4$1)4@!435``55-%4DY!344`)3`R>`!P87(M`"5S
M)7,E<R5S`'!A<FP`+G!A<@`E<R5S8V%C:&4M)7,E<P`E<R5S=&5M<"TE=25S
M`"5S)7-T96UP+25U+25U)7,`05)'5@`8`'!E<FP`4$%2.CI086-K97(Z.E9%
M4E-)3TX`,2XP-#``+64`+2T``%]?14Y67U!!4E]#3$5!3E]?("`@("`@("`@
M("`@("`@`````'!E<FQX<VDN8P```"5S.B!C<F5A=&EO;B!O9B!P<FEV871E
M('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H``"5S.B!P<FEV
M871E('-U8F1I<F5C=&]R>2`E<R!I<R!U;G-A9F4@*'!L96%S92!R96UO=F4@
M:70@86YD(')E=')Y('EO=7(@;W!E<F%T:6]N*0H``%5N86)L92!T;R!C<F5A
M=&4@8V%C:&4@9&ER96-T;W)Y`````"5S.B!C<F5A=&EO;B!O9B!P<FEV871E
M(&-A8VAE('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H`````
M979A;"`G97AE8R`O=7-R+V)I;B]P97)L("`M4R`D,"`D>S$K(B1`(GTG"FEF
M(#`[(",@;F]T(')U;FYI;F<@=6YD97(@<V]M92!S:&5L;`IP86-K86=E(%]?
M<&%R7W!L.PIM>2`H)'!A<E]T96UP+"`D<')O9VYA;64L($!T;7!F:6QE*3L*
M14Y$('L@:68@*"1%3E9[4$%27T-,14%.?2D@>PIR97%U:7)E($9I;&4Z.E1E
M;7`["G)E<75I<F4@1FEL93HZ0F%S96YA;64["G)E<75I<F4@1FEL93HZ4W!E
M8SL*;7D@)'1O<&1I<B`]($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1P87)?
M=&5M<"D["F]U=',H<7%[4F5M;W9I;F<@9FEL97,@:6X@(B1P87)?=&5M<")]
M*3L*1FEL93HZ1FEN9#HZ9FEN9&1E<'1H*'-U8B![("@@+60@*2`_(')M9&ER
M(#H@=6YL:6YK('TL("1P87)?=&5M<"D["G)M9&ER("1P87)?=&5M<#L*:68@
M*"UD("1P87)?=&5M<"`F)B`D7D\@;F4@)TU35VEN,S(G*2!["FUY("1T;7`@
M/2!N97<@1FEL93HZ5&5M<"@*5$5-4$Q!5$4@/3X@)W1M<%A86%A8)RP*1$E2
M(#T^($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1T;W!D:7(I+`I3549&25@@
M/3X@)RYC;60G+`I53DQ)3DL@/3X@,"P**3L*<')I;G0@)'1M<"`B(R$O8FEN
M+W-H"G@],3L@=VAI;&4@6R!<)'@@+6QT(#$P(%T[(&1O"G)M("UR9B`G)'!A
M<E]T96UP)PII9B!;(%PA("UD("<D<&%R7W1E;7`G(%T[('1H96X*8G)E86L*
M9FD*<VQE97`@,0IX/6!E>'!R(%PD>"`K(#%@"F1O;F4*<FT@)R(@+B`D=&UP
M+3YF:6QE;F%M92`N("(G"B(["F-H;6]D(#`W,#`L)'1M<"T^9FEL96YA;64[
M"FUY("1C;60@/2`D=&UP+3YF:6QE;F%M92`N("<@/B]D978O;G5L;"`R/B8Q
M("8G.PIC;&]S92`D=&UP.PIS>7-T96TH)&-M9"D["F]U=',H<7$H4W!A=VYE
M9"!B86-K9W)O=6YD('!R;V-E<W,@=&\@<&5R9F]R;2!C;&5A;G5P.B`I"BX@
M)'1M<"T^9FEL96YA;64I.PI]"GT@?0I"14=)3B!["DEN=&5R;F%L<SHZ4$%2
M.CI"3T]4*"D@:68@9&5F:6YE9"`F26YT97)N86QS.CI005(Z.D)/3U0["F5V
M86P@>PI?<&%R7VEN:71?96YV*"D["FUY("1Q=6EE="`]("$D14Y6>U!!4E]$
M14)51WT["FUY("5#;VYF:6<@/2`H"G!A=&A?<V5P("`@(#T^("@D7D\@/7X@
M+UY-4U=I;B\@/R`G.R<@.B`G.B<I+`I?97AE("`@("`@("`]/B`H)%Y/(#U^
M("]>*#\Z35-7:6Y\3U,R?&-Y9W=I;BDO(#\@)RYE>&4G(#H@)R<I+`I?9&5L
M:6T@("`@("`]/B`H)%Y/(#U^("]>35-7:6Y\3U,R+R`_("=<7"<@.B`G+R<I
M+`HI.PI?<V5T7W!R;V=N86UE*"D["E]S971?<&%R7W1E;7`H*3L*;7D@*"1S
M=&%R=%]P;W,L("1D871A7W!O<RD["GL*;&]C86P@)%-)1WM?7U=!4DY?7WT@
M/2!S=6(@>WT["F]P96X@7T9(+"`G/"<L("1P<F]G;F%M92!O<B!L87-T.PIB
M:6YM;V1E*%]&2"D["FUY("1B=68["FUY("1S:7IE(#T@+7,@)'!R;V=N86UE
M.PIM>2`D;V9F<V5T(#T@-3$R.PIM>2`D:61X(#T@+3$["G=H:6QE("@Q*0I[
M"B1O9F9S970@/2`D<VEZ92!I9B`D;V9F<V5T(#X@)'-I>F4["G-E96L@7T9(
M+"`M)&]F9G-E="P@,B!O<B!D:64@<7%;<V5E:R!F86EL960@;VX@(B1P<F]G
M;F%M92(Z("0A73L*;7D@)&YR96%D(#T@<F5A9"!?1D@L("1B=68L("1O9F9S
M970["F1I92!Q<5MR96%D(&9A:6QE9"!O;B`B)'!R;V=N86UE(CH@)"%=('5N
M;&5S<R`D;G)E860@/3T@)&]F9G-E=#L*)&ED>"`](')I;F1E>"@D8G5F+"`B
M7&Y005(N<&U<;B(I.PIL87-T(&EF("1I9'@@/CT@,"!\?"`D;V9F<V5T(#T]
M("1S:7IE('Q\("1O9F9S970@/B`Q,C@@*B`Q,#(T.PHD;V9F<V5T("H](#([
M"GT*;&%S="!U;FQE<W,@)&ED>"`^/2`P.PHD;V9F<V5T("T]("1I9'@@+2`T
M.PIS965K(%]&2"P@+21O9F9S970L(#(["G)E860@7T9(+"`D8G5F+"`T.PIS
M965K(%]&2"P@+21O9F9S970@+2!U;G!A8VLH(DXB+"`D8G5F*2P@,CL*<F5A
M9"!?1D@L("1B=68L(#0["B1D871A7W!O<R`]("AT96QL(%]&2"D@+2`T.PIM
M>2`E<F5Q=6ER95]L:7-T.PIW:&EL92`H)&)U9B!E<2`B1DE,12(I('L*<F5A
M9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D
M8G5F*3L*;7D@)&9U;&QN86UE(#T@)&)U9CL*;W5T<RAQ<2A5;G!A8VMI;F<@
M9FEL92`B)&9U;&QN86UE(BXN+BDI.PIM>2`D8W)C(#T@*"`D9G5L;&YA;64@
M/7X@<WQ>*%MA+69<9%U[.'TI+WQ\("D@/R`D,2`Z('5N9&5F.PIM>2`H)&)A
M<V5N86UE+"`D97AT*2`]("@D8G5F(#U^(&U\*#\Z+BHO*3\H+BHI*%PN+BHI
M?"D["G)E860@7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K
M*").(BP@)&)U9BD["FEF("AD969I;F5D*"1E>'0I(&%N9"`D97AT("%^("]<
M+B@_.G!M?'!L?&EX?&%L*20O:2D@>PIM>2`D9FEL96YA;64@/2!?=&5M<&9I
M;&4H(B1C<F,D97AT(BP@)&)U9BP@,#<U-2D["B1005(Z.DAE879Y.CI&=6QL
M0V%C:&5[)&9U;&QN86UE?2`]("1F:6QE;F%M93L*)%!!4CHZ2&5A=GDZ.D9U
M;&Q#86-H97LD9FEL96YA;65](#T@)&9U;&QN86UE.PI]"F5L<VEF("@@)&9U
M;&QN86UE(#U^(&U\7B\_<VAL:6(O?"!A;F0@9&5F:6YE9"`D14Y6>U!!4E]4
M14U0?2`I('L*;7D@)&9I;&5N86UE(#T@7W1E;7!F:6QE*"(D8F%S96YA;64D
M97AT(BP@)&)U9BP@,#<U-2D["F]U=',H(E-(3$E".B`D9FEL96YA;65<;B(I
M.PI]"F5L<V4@>PHD<F5Q=6ER95]L:7-T>R1F=6QL;F%M97T@/0HD4$%2.CI(
M96%V>3HZ36]D=6QE0V%C:&5[)&9U;&QN86UE?2`]('L*8G5F(#T^("1B=68L
M"F-R8R`]/B`D8W)C+`IN86UE(#T^("1F=6QL;F%M92P*?3L*?0IR96%D(%]&
M2"P@)&)U9BP@-#L*?0IL;V-A;"!`24Y#(#T@*'-U8B!["FUY("@D<V5L9BP@
M)&UO9'5L92D@/2!`7SL*<F5T=7)N(&EF(')E9B`D;6]D=6QE(&]R("$D;6]D
M=6QE.PIM>2`D9FEL96YA;64@/2!D96QE=&4@)')E<75I<F5?;&ES='LD;6]D
M=6QE?2!\?"!D;R!["FUY("1K97D["F9O<F5A8V@@*&ME>7,@)7)E<75I<F5?
M;&ES="D@>PIN97AT('5N;&5S<R`O7%$D;6]D=6QE7$4D+SL*)&ME>2`]("1?
M.R!L87-T.PI]"F1E;&5T92`D<F5Q=6ER95]L:7-T>R1K97E](&EF(&1E9FEN
M960H)&ME>2D["GT@;W(@<F5T=7)N.PHD24Y#>R1M;V1U;&5](#T@(B]L;V%D
M97(O)&9I;&5N86UE+R1M;V1U;&4B.PII9B`H)$5.5GM005)?0TQ%04Y](&%N
M9"!D969I;F5D*"9)3SHZ1FEL93HZ;F5W*2D@>PIM>2`D9F@@/2!)3SHZ1FEL
M92T^;F5W7W1M<&9I;&4@;W(@9&EE("0A.PIB:6YM;V1E*"1F:"D["G!R:6YT
M("1F:"`D9FEL96YA;64M/GMB=69].PIS965K*"1F:"P@,"P@,"D["G)E='5R
M;B`D9F@["GT*96QS92!["FUY("1F:6QE;F%M92`](%]T96UP9FEL92@B)&9I
M;&5N86UE+3Y[8W)C?2YP;2(L("1F:6QE;F%M92T^>V)U9GTI.PIO<&5N(&UY
M("1F:"P@)SPG+"`D9FEL96YA;64@;W(@9&EE(")C86XG="!R96%D("1F:6QE
M;F%M93H@)"$B.PIB:6YM;V1E*"1F:"D["G)E='5R;B`D9F@["GT*9&EE(")"
M;V]T<W1R87!P:6YG(&9A:6QE9#H@8V%N;F]T(&9I;F0@)&UO9'5L92%<;B([
M"GTL($!)3D,I.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E(%!!4CHZ2&5A
M=GD["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@17AP;W)T97(Z.DAE
M879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["G)E<75I<F4@
M24\Z.D9I;&4["G=H:6QE("AM>2`D9FEL96YA;64@/2`H<V]R="!K97ES("5R
M97%U:7)E7VQI<W0I6S!=*2!["G5N;&5S<R`H)$E.0WLD9FEL96YA;65](&]R
M("1F:6QE;F%M92`]?B`O0E-$4$%.+RD@>PII9B`H)&9I;&5N86UE(#U^("]<
M+G!M8S\D+VDI('L*<F5Q=6ER92`D9FEL96YA;64["GT*96QS92!["F1O("1F
M:6QE;F%M92!U;FQE<W,@)&9I;&5N86UE(#U^("]S:71E8W5S=&]M:7IE7"YP
M;"0O.PI]"GT*9&5L971E("1R97%U:7)E7VQI<W1[)&9I;&5N86UE?3L*?0IL
M87-T('5N;&5S<R`D8G5F(&5Q(")02UPP,#-<,#`T(CL*)'-T87)T7W!O<R`]
M("AT96QL(%]&2"D@+2`T.PI]"FUY($!P87)?87)G<SL*;7D@*"1O=70L("1B
M=6YD;&4L("1L;V=F:"P@)&-A8VAE7VYA;64I.PID96QE=&4@)$5.5GM005)?
M05!07U)%55-%?3L@(R!S86YI=&EZ92`H4D554T4@;6%Y(&)E(&$@<V5C=7)I
M='D@<')O8FQE;2D*)'%U:65T(#T@,"!U;FQE<W,@)$5.5GM005)?1$5"54=]
M.PII9B`H(21S=&%R=%]P;W,@;W(@*"1!4D=66S!=(&5Q("<M+7!A<BUO<'1I
M;VYS)R`F)B!S:&EF="DI('L*;7D@)61I<W1?8VUD(#T@<7<H"G`@("!B;&EB
M7W1O7W!A<@II("`@:6YS=&%L;%]P87(*=2`@('5N:6YS=&%L;%]P87(*<R`@
M('-I9VY?<&%R"G8@("!V97)I9GE?<&%R"BD["FEF("A`05)'5B!A;F0@)$%2
M1U9;,%T@97$@)RTM<F5U<V4G*2!["G-H:69T($!!4D=6.PHD14Y6>U!!4E]!
M4%!?4D554T5](#T@<VAI9G0@0$%21U8["GT*96QS92![(",@;F]R;6%L('!A
M<FP@8F5H879I;W5R"FUY($!A9&1?=&]?:6YC.PIW:&EL92`H0$%21U8I('L*
M)$%21U9;,%T@/7X@+UXM*%M!24U/0DQB<7!I=7-4=ETI*"XJ*2\@;W(@;&%S
M=#L*:68@*"0Q(&5Q("=))RD@>PIP=7-H($!A9&1?=&]?:6YC+"`D,CL*?0IE
M;'-I9B`H)#$@97$@)TTG*2!["F5V86P@(G5S92`D,B(["GT*96QS:68@*"0Q
M(&5Q("=!)RD@>PIU;G-H:69T($!P87)?87)G<RP@)#(["GT*96QS:68@*"0Q
M(&5Q("=/)RD@>PHD;W5T(#T@)#(["GT*96QS:68@*"0Q(&5Q("=B)RD@>PHD
M8G5N9&QE(#T@)W-I=&4G.PI]"F5L<VEF("@D,2!E<2`G0B<I('L*)&)U;F1L
M92`]("=A;&PG.PI]"F5L<VEF("@D,2!E<2`G<2<I('L*)'%U:65T(#T@,3L*
M?0IE;'-I9B`H)#$@97$@)TPG*2!["F]P96X@)&QO9V9H+"`B/CXB+"`D,B!O
M<B!D:64@(EA86#H@0V%N;F]T(&]P96X@;&]G.B`D(2(["GT*96QS:68@*"0Q
M(&5Q("=4)RD@>PHD8V%C:&5?;F%M92`]("0R.PI]"G-H:69T*$!!4D=6*3L*
M:68@*&UY("1C;60@/2`D9&ES=%]C;61[)#%]*2!["F1E;&5T92`D14Y6>R=0
M05)?5$5-4"=].PII;FET7VEN8R@I.PIR97%U:7)E(%!!4CHZ1&ES=#L*)GLB
M4$%2.CI$:7-T.CHD8VUD(GTH*2!U;FQE<W,@0$%21U8["B9[(E!!4CHZ1&ES
M=#HZ)&-M9")]*"1?*2!F;W(@0$%21U8["F5X:70["GT*?0IU;G-H:69T($!)
M3D,L($!A9&1?=&]?:6YC.PI]"GT*:68@*"1O=70I('L*>PIR97%U:7)E($E/
M.CI&:6QE.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*?0IM>2`D<&%R(#T@<VAI
M9G0H0$%21U8I.PIM>2`D>FEP.PII9B`H9&5F:6YE9"`D<&%R*2!["D%R8VAI
M=F4Z.EII<#HZ<V5T0VAU;FM3:7IE*#$R."HQ,#(T*3L*;W!E;B!M>2`D9F@L
M("<\)RP@)'!A<B!O<B!D:64@(D-A;FYO="!F:6YD("<D<&%R)SH@)"$B.PIB
M:6YM;V1E*"1F:"D["F)L97-S*"1F:"P@)TE/.CI&:6QE)RD["B1Z:7`@/2!!
M<F-H:79E.CI::7`M/FYE=SL**"`D>FEP+3YR96%D1G)O;49I;&5(86YD;&4H
M)&9H+"`D<&%R*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@*0IO<B!D:64@
M(E)E860@)R1P87(G(&5R<F]R.B`D(2(["GT*;7D@)65N=B`](&1O('L*:68@
M*"1Z:7`@86YD(&UY("1M971A(#T@)'II<"T^8V]N=&5N=',H)TU%5$$N>6UL
M)RDI('L*)&UE=&$@/7X@<R\N*EYP87(Z)"\O;7,["B1M971A(#U^(',O7EQ3
M+BHO+VUS.PHD;65T82`]?B`O7B`@*%M>.ETK*3H@*"XK*20O;6<["GT*?3L*
M;&]C86P@)"\@/2!<-#L*:68@*&1E9FEN960@)'!A<BD@>PIO<&5N(%!!4BP@
M)SPG+"`D<&%R(&]R(&1I92`B)"$Z("1P87(B.PIB:6YM;V1E*%!!4BD["F1I
M92`B)'!A<B!I<R!N;W0@82!005(@9FEL92(@=6YL97-S(#Q005(^(&5Q(")0
M2UPP,#-<,#`T(CL*?0I#<F5A=&50871H*"1O=70I(#L*;7D@)&9H(#T@24\Z
M.D9I;&4M/FYE=R@*)&]U="P*24\Z.D9I;&4Z.D]?0U)%050H*2!\($E/.CI&
M:6QE.CI/7U=23TY,62@I('P@24\Z.D9I;&4Z.D]?5%)53D,H*2P*,#<W-RP*
M*2!O<B!D:64@)"$["F)I;FUO9&4H)&9H*3L*)"\@/2`H9&5F:6YE9"`D9&%T
M85]P;W,I(#\@7"1D871A7W!O<R`Z('5N9&5F.PIS965K(%]&2"P@,"P@,#L*
M;7D@)&QO861E<B`]('-C86QA<B`\7T9(/CL*:68@*"$D14Y6>U!!4E]615)"
M051)37T@86YD("1L;V%D97(@/7X@+UXH/SHC(7Q<0')E;2DO*2!["G)E<75I
M<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PI005(Z.D9I;'1E<CHZ4&]D4W1R
M:7`M/FYE=RT^87!P;'DH7"1L;V%D97(L("0P*0I]"F9O<F5A8V@@;7D@)&ME
M>2`H<V]R="!K97ES("5E;G8I('L*;7D@)'9A;"`]("1E;G9[)&ME>7T@;W(@
M;F5X=#L*)'9A;"`](&5V86P@)'9A;"!I9B`D=F%L(#U^("]>6R<B72\["FUY
M("1M86=I8R`](")?7T5.5E]005)?(B`N('5C*"1K97DI("X@(E]?(CL*;7D@
M)'-E="`](")005)?(B`N('5C*"1K97DI("X@(CTD=F%L(CL*)&QO861E<B`]
M?B!S>R1M86=I8R@@*RE]>PHD;6%G:6,@+B`D<V5T("X@*"<@)R!X("AL96YG
M=&@H)#$I("T@;&5N9W1H*"1S970I*2D*?65G.PI]"B1F:"T^<')I;G0H)&QO
M861E<BD["B0O(#T@=6YD968["FEF("@D8G5N9&QE*2!["G)E<75I<F4@4$%2
M.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PII;FET
M7VEN8R@I.PIR97%U:7)E7VUO9'5L97,H*3L*;7D@0&EN8R`](&=R97`@>R`A
M+T)31%!!3B\@?0IG<F5P('L**"1B=6YD;&4@;F4@)W-I=&4G*2!O<@HH)%\@
M;F4@)$-O;F9I9SHZ0V]N9FEG>V%R8VAL:6)E>'!](&%N9`HD7R!N92`D0V]N
M9FEG.CI#;VYF:6=[<')I=FQI8F5X<'TI.PI]($!)3D,["FUY("5F:6QE<SL*
M)&9I;&5S>R1??2LK(&9O<B!`1'EN84QO861E<CHZ9&Q?<VAA<F5D7V]B:F5C
M=',L('9A;'5E<R`E24Y#.PIM>2`D;&EB7V5X="`]("1#;VYF:6<Z.D-O;F9I
M9WML:6)?97AT?3L*;7D@)7=R:71T96X["F9O<F5A8V@@*'-O<G0@:V5Y<R`E
M9FEL97,I('L*;7D@*"1N86UE+"`D9FEL92D["F9O<F5A8V@@;7D@)&1I<B`H
M0&EN8RD@>PII9B`H)&YA;64@/2`D4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1?
M?2D@>PHD9FEL92`]("1?.PIL87-T.PI]"F5L<VEF("@O7BA<421D:7)<15PO
M*"XJ6UY#8UTI*5Q:+VDI('L**"1F:6QE+"`D;F%M92D@/2`H)#$L("0R*3L*
M;&%S=#L*?0IE;'-I9B`H;2%>+VQO861E<B];7B]=*R\H+BI;7D-C72E<6B$I
M('L*:68@*&UY("1R968@/2`D4$%2.CI(96%V>3HZ36]D=6QE0V%C:&5[)#%]
M*2!["B@D9FEL92P@)&YA;64I(#T@*"1R968L("0Q*3L*;&%S=#L*?0IE;'-I
M9B`H+68@(B1D:7(O)#$B*2!["B@D9FEL92P@)&YA;64I(#T@*"(D9&ER+R0Q
M(BP@)#$I.PIL87-T.PI]"GT*?0IN97AT('5N;&5S<R!D969I;F5D("1N86UE
M(&%N9"!N;W0@)'=R:71T96Y[)&YA;65]*RL["FYE>'0@:68@(7)E9B@D9FEL
M92D@86YD("1F:6QE(#U^("]<+EQ1)&QI8E]E>'1<120O.PIO=71S*"!J;VEN
M("(B+`IQ<2A086-K:6YG("(I+"!R968@)&9I;&4@/R`D9FEL92T^>VYA;65]
M(#H@)&9I;&4L"G%Q*"(N+BXI"BD["FUY("1C;VYT96YT.PII9B`H<F5F*"1F
M:6QE*2D@>PHD8V]N=&5N="`]("1F:6QE+3Y[8G5F?3L*?0IE;'-E('L*;W!E
M;B!&24Q%+"`G/"<L("1F:6QE(&]R(&1I92`B0V%N)W0@;W!E;B`D9FEL93H@
M)"$B.PIB:6YM;V1E*$9)3$4I.PHD8V]N=&5N="`](#Q&24Q%/CL*8VQO<V4@
M1DE,13L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YN97<M/F%P<&QY*%PD8V]N
M=&5N="P@)&9I;&4I"FEF("$D14Y6>U!!4E]615)"051)37T@86YD("1N86UE
M(#U^("]<+B@_.G!M?&EX?&%L*20O:3L*4$%2.CI&:6QT97(Z.E!A=&-H0V]N
M=&5N="T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE+"`D;F%M92D["GT*
M;W5T<RAQ<2A7<FET=&5N(&%S("(D;F%M92(I*3L*)&9H+3YP<FEN="@B1DE,
M12(I.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"!L96YG=&@H)&YA;64I("L@.2DI
M.PHD9F@M/G!R:6YT*'-P<FEN=&8H"B(E,#AX+R5S(BP@07)C:&EV93HZ6FEP
M.CIC;VUP=71E0U)#,S(H)&-O;G1E;G0I+"`D;F%M90HI*3L*)&9H+3YP<FEN
M="AP86-K*"=.)RP@;&5N9W1H*"1C;VYT96YT*2DI.PHD9F@M/G!R:6YT*"1C
M;VYT96YT*3L*?0I]"B1Z:7`M/G=R:71E5&]&:6QE2&%N9&QE*"1F:"D@:68@
M)'II<#L*)&-A8VAE7VYA;64@/2!S=6)S='(@)&-A8VAE7VYA;64L(#`L(#0P
M.PII9B`H(21C86-H95]N86UE(&%N9"!M>2`D;71I;64@/2`H<W1A="@D;W5T
M*2E;.5TI('L*;7D@)&-T>"`](&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!
M.R!$:6=E<W0Z.E-(02T^;F5W*#$I('T*?'P@979A;"![(')E<75I<F4@1&EG
M97-T.CI32$$Q.R!$:6=E<W0Z.E-(03$M/FYE=R!]"GQ\(&5V86P@>R!R97%U
M:7)E($1I9V5S=#HZ340U.R!$:6=E<W0Z.DU$-2T^;F5W('T["FUY("1S:&%?
M=F5R<VEO;B`](&5V86P@>R`D1&EG97-T.CI32$$Z.E9%4E-)3TX@?2!\?"`P
M.PII9B`H)'-H85]V97)S:6]N(&5Q("<U+C,X)R!O<B`D<VAA7W9E<G-I;VX@
M97$@)S4N,SDG*2!["B1C='@M/F%D9&9I;&4H)&]U="P@(F(B*2!I9B`H)&-T
M>"D["GT*96QS92!["FEF("@D8W1X(&%N9"!O<&5N*&UY("1F:"P@(CPD;W5T
M(BDI('L*8FEN;6]D92@D9F@I.PHD8W1X+3YA9&1F:6QE*"1F:"D["F-L;W-E
M*"1F:"D["GT*?0HD8V%C:&5?;F%M92`]("1C='@@/R`D8W1X+3YH97AD:6=E
M<W0@.B`D;71I;64["GT*)&-A8VAE7VYA;64@+CT@(EPP(B!X("@T,2`M(&QE
M;F=T:"`D8V%C:&5?;F%M92D["B1C86-H95]N86UE("X](")#04-(12(["B1F
M:"T^<')I;G0H)&-A8VAE7VYA;64I.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"`D
M9F@M/G1E;&P@+2!L96YG=&@H)&QO861E<BDI*3L*)&9H+3YP<FEN="@B7&Y0
M05(N<&U<;B(I.PHD9F@M/F-L;W-E.PIC:&UO9"`P-S4U+"`D;W5T.PIE>&ET
M.PI]"GL*;&%S="!U;FQE<W,@9&5F:6YE9"`D<W1A<G1?<&]S.PI?9FEX7W!R
M;V=N86UE*"D["G)E<75I<F4@4$%2.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA
M;&]A9&5R*"D["GL*<F5Q=6ER92!&:6QE.CI&:6YD.PIR97%U:7)E($%R8VAI
M=F4Z.EII<#L*?0IM>2`D>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["FUY("1F
M:"`]($E/.CI&:6QE+3YN97<["B1F:"T^9F1O<&5N*&9I;&5N;RA?1D@I+"`G
M<B<I(&]R(&1I92`B)"$Z("1`(CL*)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE
M*"1F:"P@)'!R;V=N86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@;W(@
M9&EE("(D(3H@)$`B.PIP=7-H($!005(Z.DQI8D-A8VAE+"`D>FEP.PHD4$%2
M.CI,:6)#86-H97LD<')O9VYA;65](#T@)'II<#L*)'%U:65T(#T@(21%3E9[
M4$%27T1%0E5'?3L*;W5T<RAQ<2A<)$5.5GM005)?5$5-4'T@/2`B)$5.5GM0
M05)?5$5-4'TB*2D["FEF("AD969I;F5D("1%3E9[4$%27U1%35!]*2![(",@
M<VAO=6QD(&)E('-E="!A="!T:&ES('!O:6YT(0IF;W)E86-H(&UY("1M96UB
M97(@*"`D>FEP+3YM96UB97)S("D@>PIN97AT(&EF("1M96UB97(M/FES1&ER
M96-T;W)Y.PIM>2`D;65M8F5R7VYA;64@/2`D;65M8F5R+3YF:6QE3F%M93L*
M;F5X="!U;FQE<W,@)&UE;6)E<E]N86UE(#U^(&U["EX*+S]S:&QI8B\**#\Z
M)$-O;F9I9SHZ0V]N9FEG>W9E<G-I;VY]+RD_"B@_.B1#;VYF:6<Z.D-O;F9I
M9WMA<F-H;F%M97TO*3\**%M>+UTK*0HD"GUX.PIM>2`D97AT<F%C=%]N86UE
M(#T@)#$["FUY("1D97-T7VYA;64@/2!&:6QE.CI3<&5C+3YC871F:6QE*"1%
M3E9[4$%27U1%35!]+"`D97AT<F%C=%]N86UE*3L*:68@*"UF("1D97-T7VYA
M;64@)B8@+7,@7R`]/2`D;65M8F5R+3YU;F-O;7!R97-S9613:7IE*"DI('L*
M;W5T<RAQ<2A3:VEP<&EN9R`B)&UE;6)E<E]N86UE(B!S:6YC92!I="!A;')E
M861Y(&5X:7-T<R!A="`B)&1E<W1?;F%M92(I*3L*?2!E;'-E('L*;W5T<RAQ
M<2A%>'1R86-T:6YG("(D;65M8F5R7VYA;64B('1O("(D9&5S=%]N86UE(BDI
M.PHD;65M8F5R+3YE>'1R86-T5&]&:6QE3F%M960H)&1E<W1?;F%M92D["F-H
M;6]D*#`U-34L("1D97-T7VYA;64I(&EF("1>3R!E<2`B:'!U>"(["GT*?0I]
M"GT*=6YL97-S("@D4$%2.CI,:6)#86-H97LD<')O9VYA;65]*2!["F1I92`\
M/"`B+B(@=6YL97-S($!!4D=6.PI5<V%G93H@)#`@6R`M06QI8BYP87(@72!;
M("U)9&ER(%T@6R`M36UO9'5L92!=(%L@<W)C+G!A<B!=(%L@<')O9W)A;2YP
M;"!="B0P(%L@+4)\+6(@72!;+4]O=71F:6QE72!S<F,N<&%R"BX*)$5.5GM0
M05)?4%)/1TY!345](#T@)'!R;V=N86UE(#T@)#`@/2!S:&EF="A`05)'5BD[
M"GT*<W5B($-R96%T95!A=&@@>PIM>2`H)&YA;64I(#T@0%\["G)E<75I<F4@
M1FEL93HZ0F%S96YA;64["FUY("@D8F%S96YA;64L("1P871H+"`D97AT*2`]
M($9I;&4Z.D)A<V5N86UE.CIF:6QE<&%R<V4H)&YA;64L("@G7"XN*B<I*3L*
M<F5Q=6ER92!&:6QE.CI0871H.PI&:6QE.CI0871H.CIM:W!A=&@H)'!A=&@I
M('5N;&5S<R@M92`D<&%T:"D[(",@;6MP871H(&1I97,@=VET:"!E<G)O<@I]
M"G-U8B!R97%U:7)E7VUO9'5L97,@>PIR97%U:7)E(&QI8CL*<F5Q=6ER92!$
M>6YA3&]A9&5R.PIR97%U:7)E(&EN=&5G97(["G)E<75I<F4@<W1R:6-T.PIR
M97%U:7)E('=A<FYI;F=S.PIR97%U:7)E('9A<G,["G)E<75I<F4@0V%R<#L*
M<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%<G)N;SL*<F5Q=6ER92!%
M>'!O<G1E<CHZ2&5A=GD["G)E<75I<F4@17AP;W)T97(["G)E<75I<F4@1F-N
M=&P["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI3<&5C.PIR
M97%U:7)E(%A33&]A9&5R.PIR97%U:7)E($-O;F9I9SL*<F5Q=6ER92!)3SHZ
M2&%N9&QE.PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($-O;7!R97-S.CI:
M;&EB.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!005(["G)E<75I
M<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!005(Z.D1I<W0["G)E<75I<F4@4$%2
M.CI&:6QT97(Z.E!O9%-T<FEP.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0871C
M:$-O;G1E;G0["G)E<75I<F4@871T<FEB=71E<SL*979A;"![(')E<75I<F4@
M0W=D('T["F5V86P@>R!R97%U:7)E(%=I;C,R('T["F5V86P@>R!R97%U:7)E
M(%-C86QA<CHZ571I;"!].PIE=F%L('L@<F5Q=6ER92!!<F-H:79E.CI5;GII
M<#HZ0G5R<W0@?3L*979A;"![(')E<75I<F4@5&EE.CI(87-H.CI.86UE9$-A
M<'1U<F4@?3L*979A;"![(')E<75I<F4@4&5R;$E/.R!R97%U:7)E(%!E<FQ)
M3SHZ<V-A;&%R('T["F5V86P@>R!R97%U:7)E('5T9C@@?3L*?0IS=6(@7W-E
M=%]P87)?=&5M<"!["FEF("AD969I;F5D("1%3E9[4$%27U1%35!](&%N9"`D
M14Y6>U!!4E]414U0?2`]?B`O*"XK*2\I('L*)'!A<E]T96UP(#T@)#$["G)E
M='5R;CL*?0IF;W)E86-H(&UY("1P871H("@**&UA<"`D14Y6>R1??2P@<7<H
M(%!!4E]435!$25(@5$U01$E2(%1%35!$25(@5$5-4"!435`@*2DL"G%W*"!#
M.EQ<5$5-4"`O=&UP("X@*0HI('L*;F5X="!U;FQE<W,@9&5F:6YE9"`D<&%T
M:"!A;F0@+60@)'!A=&@@86YD("UW("1P871H.PIM>2`D=7-E<FYA;64["FUY
M("1P=W5I9#L*979A;"![*"1P=W5I9"D@/2!G971P=W5I9"@D/BD@:68@9&5F
M:6YE9"`D/CM].PII9B`H(&1E9FEN960H)E=I;C,R.CI,;V=I;DYA;64I("D@
M>PHD=7-E<FYA;64@/2`F5VEN,S(Z.DQO9VEN3F%M93L*?0IE;'-I9B`H9&5F
M:6YE9"`D<'=U:60I('L*)'5S97)N86UE(#T@)'!W=6ED.PI]"F5L<V4@>PHD
M=7-E<FYA;64@/2`D14Y6>U5315).04U%?2!\?"`D14Y6>U5315)]('Q\("=3
M65-414TG.PI]"B1U<V5R;F%M92`]?B!S+UQ7+U\O9SL*;7D@)'-T;7!D:7(@
M/2`B)'!A=&@D0V]N9FEG>U]D96QI;7UP87(M(BYU;G!A8VLH(D@J(BP@)'5S
M97)N86UE*3L*;6MD:7(@)'-T;7!D:7(L(#`W-34["FEF("@A)$5.5GM005)?
M0TQ%04Y](&%N9"!M>2`D;71I;64@/2`H<W1A="@D<')O9VYA;64I*5LY72D@
M>PIO<&5N("AM>2`D9F@L("(\(BX@)'!R;V=N86UE*3L*<V5E:R`D9F@L("TQ
M."P@,CL*<WES<F5A9"`D9F@L(&UY("1B=68L(#8["FEF("@D8G5F(&5Q(")<
M,$-!0TA%(BD@>PIS965K("1F:"P@+34X+"`R.PIS>7-R96%D("1F:"P@)&)U
M9BP@-#$["B1B=68@/7X@<R]<,"\O9SL*)'-T;7!D:7(@+CT@(B1#;VYF:6=[
M7V1E;&EM?6-A8VAE+2(@+B`D8G5F.PI]"F5L<V4@>PIM>2`D8W1X(#T@979A
M;"![(')E<75I<F4@1&EG97-T.CI32$$[($1I9V5S=#HZ4TA!+3YN97<H,2D@
M?0I\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03$[($1I9V5S=#HZ4TA!
M,2T^;F5W('T*?'P@979A;"![(')E<75I<F4@1&EG97-T.CI-1#4[($1I9V5S
M=#HZ340U+3YN97<@?3L*;7D@)'-H85]V97)S:6]N(#T@979A;"![("1$:6=E
M<W0Z.E-(03HZ5D524TE/3B!]('Q\(#`["FEF("@D<VAA7W9E<G-I;VX@97$@
M)S4N,S@G(&]R("1S:&%?=F5R<VEO;B!E<2`G-2XS.2<I('L*)&-T>"T^861D
M9FEL92@D<')O9VYA;64L(")B(BD@:68@*"1C='@I.PI]"F5L<V4@>PII9B`H
M)&-T>"!A;F0@;W!E;BAM>2`D9F@L("(\)'!R;V=N86UE(BDI('L*8FEN;6]D
M92@D9F@I.PHD8W1X+3YA9&1F:6QE*"1F:"D["F-L;W-E*"1F:"D["GT*?0HD
M<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]8V%C:&4M(B`N("@@)&-T>"`_
M("1C='@M/FAE>&1I9V5S="`Z("1M=&EM92`I.PI]"F-L;W-E*"1F:"D["GT*
M96QS92!["B1%3E9[4$%27T-,14%.?2`](#$["B1S=&UP9&ER("X]("(D0V]N
M9FEG>U]D96QI;7UT96UP+20D(CL*?0HD14Y6>U!!4E]414U0?2`]("1S=&UP
M9&ER.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*;&%S=#L*?0HD<&%R7W1E;7`@
M/2`D,2!I9B`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@
M+R@N*RDO.PI]"G-U8B!?=&5M<&9I;&4@>PIM>2`H)&YA;64L("1C;VYT96YT
M<RP@)&UO9&4I(#T@0%\["FUY("1F=6QL;F%M92`]("(D<&%R7W1E;7`O)&YA
M;64B.PIU;FQE<W,@*"UE("1F=6QL;F%M92D@>PIM>2`D=&5M<&YA;64@/2`B
M)&9U;&QN86UE+B0D(CL*;W!E;B!M>2`D9F@L("<^)RP@)'1E;7!N86UE(&]R
M(&1I92`B8V%N)W0@=W)I=&4@)'1E;7!N86UE.B`D(2(["F)I;FUO9&4@)&9H
M.PIP<FEN="`D9F@@)&-O;G1E;G1S.PIC;&]S92`D9F@["F-H;6]D("1M;V1E
M+"`D=&5M<&YA;64@:68@9&5F:6YE9"`D;6]D93L*<F5N86UE*"1T96UP;F%M
M92P@)&9U;&QN86UE*2!O<B!U;FQI;FLH)'1E;7!N86UE*3L*?0IR971U<FX@
M)&9U;&QN86UE.PI]"G-U8B!?<V5T7W!R;V=N86UE('L*:68@*&1E9FEN960@
M)$5.5GM005)?4%)/1TY!345](&%N9"`D14Y6>U!!4E]04D]'3D%-17T@/7X@
M+R@N*RDO*2!["B1P<F]G;F%M92`]("0Q.PI]"B1P<F]G;F%M92!\?#T@)#`[
M"FEF("@D14Y6>U!!4E]414U0?2!A;F0@:6YD97@H)'!R;V=N86UE+"`D14Y6
M>U!!4E]414U0?2D@/CT@,"D@>PHD<')O9VYA;64@/2!S=6)S='(H)'!R;V=N
M86UE+"!R:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI("L@,2D[
M"GT*:68@*"$D14Y6>U!!4E]04D]'3D%-17T@;W(@:6YD97@H)'!R;V=N86UE
M+"`D0V]N9FEG>U]D96QI;7TI(#X](#`I('L*:68@*&]P96X@;7D@)&9H+"`G
M/"<L("1P<F]G;F%M92D@>PIR971U<FX@:68@+7,@)&9H.PI]"FEF("@M<R`B
M)'!R;V=N86UE)$-O;F9I9WM?97AE?2(I('L*)'!R;V=N86UE("X]("1#;VYF
M:6=[7V5X97T["G)E='5R;CL*?0I]"F9O<F5A8V@@;7D@)&1I<B`H<W!L:70@
M+UQ1)$-O;F9I9WMP871H7W-E<'U<12\L("1%3E9[4$%42'TI('L*;F5X="!I
M9B!E>&ES=',@)$5.5GM005)?5$5-4'T@86YD("1D:7(@97$@)$5.5GM005)?
M5$5-4'T["B1D:7(@/7X@<R]<421#;VYF:6=[7V1E;&EM?5Q%)"\O.PHH*"1P
M<F]G;F%M92`]("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE)$-O;F9I
M9WM?97AE?2(I+"!L87-T*0II9B`M<R`B)&1I<B1#;VYF:6=[7V1E;&EM?21P
M<F]G;F%M921#;VYF:6=[7V5X97TB.PHH*"1P<F]G;F%M92`]("(D9&ER)$-O
M;F9I9WM?9&5L:6U])'!R;V=N86UE(BDL(&QA<W0I"FEF("US("(D9&ER)$-O
M;F9I9WM?9&5L:6U])'!R;V=N86UE(CL*?0I]"G-U8B!?9FEX7W!R;V=N86UE
M('L*)#`@/2`D<')O9VYA;64@?'P]("1%3E9[4$%27U!23T=.04U%?3L*:68@
M*&EN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`\(#`I('L*)'!R
M;V=N86UE(#T@(BXD0V]N9FEG>U]D96QI;7TD<')O9VYA;64B.PI]"FUY("1P
M=V0@/2`H9&5F:6YE9"`F0W=D.CIG971C=V0I(#\@0W=D.CIG971C=V0H*0HZ
M("@H9&5F:6YE9"`F5VEN,S(Z.D=E=$-W9"D@/R!7:6XS,CHZ1V5T0W=D*"D@
M.B!@<'=D8"D["F-H;VUP*"1P=V0I.PHD<')O9VYA;64@/7X@<R]>*#\]7"Y<
M+C]<421#;VYF:6=[7V1E;&EM?5Q%*2\D<'=D)$-O;F9I9WM?9&5L:6U]+SL*
M)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE.PI]"G-U8B!?<&%R7VEN
M:71?96YV('L*:68@*"`D14Y6>U!!4E])3DE424%,25I%1'TK*R`]/2`Q("D@
M>PIR971U<FX["GT@96QS92!["B1%3E9[4$%27TE.251)04Q)6D5$?2`](#([
M"GT*9F]R("AQ=R@@4U!!5TY%1"!414U0($-,14%.($1%0E5'($-!0TA%(%!2
M3T=.04U%($%21T,@05)'5E\P("D@*2!["F1E;&5T92`D14Y6>R=005)?)RXD
M7WT["GT*9F]R("AQ=R\@5$U01$E2(%1%35`@0TQ%04X@1$5"54<@+RD@>PHD
M14Y6>R=005)?)RXD7WT@/2`D14Y6>R=005)?1TQ/0D%,7R<N)%]](&EF(&5X
M:7-T<R`D14Y6>R=005)?1TQ/0D%,7R<N)%]].PI]"FUY("1P87)?8VQE86X@
M/2`B7U]%3E9?4$%27T-,14%.7U\@("`@("`@("`@("`@("`B.PII9B`H)$5.
M5GM005)?5$5-4'TI('L*9&5L971E("1%3E9[4$%27T-,14%.?3L*?0IE;'-I
M9B`H(65X:7-T<R`D14Y6>U!!4E]'3$]"04Q?0TQ%04Y]*2!["FUY("1V86QU
M92`]('-U8G-T<B@D<&%R7V-L96%N+"`Q,B`K(&QE;F=T:"@B0TQ%04XB*2D[
M"B1%3E9[4$%27T-,14%.?2`]("0Q(&EF("1V86QU92`]?B`O7E!!4E]#3$5!
M3CTH7%,K*2\["GT*?0IS=6(@;W5T<R!["G)E='5R;B!I9B`D<75I970["FEF
M("@D;&]G9F@I('L*<')I;G0@)&QO9V9H(")`7UQN(CL*?0IE;'-E('L*<')I
M;G0@(D!?7&XB.PI]"GT*<W5B(&EN:71?:6YC('L*<F5Q=6ER92!#;VYF:6<[
M"G!U<V@@0$E.0RP@9W)E<"!D969I;F5D+"!M87`@)$-O;F9I9SHZ0V]N9FEG
M>R1??2P@<7<H"F%R8VAL:6)E>'`@<')I=FQI8F5X<"!S:71E87)C:&5X<"!S
M:71E;&EB97AP"G9E;F1O<F%R8VAE>'`@=F5N9&]R;&EB97AP"BD["GT*<&%C
M:V%G92!M86EN.PIR97%U:7)E(%!!4CL*=6YS:&EF="!`24Y#+"!<)E!!4CHZ
M9FEN9%]P87(["E!!4BT^:6UP;W)T*$!P87)?87)G<RD["F1I92!Q<2AP87(N
M<&PZ($-A;B=T(&]P96X@<&5R;"!S8W)I<'0@(B1P<F]G;F%M92(Z($YO('-U
M8V@@9FEL92!O<B!D:7)E8W1O<GE<;BD*=6YL97-S("UE("1P<F]G;F%M93L*
M9&\@)'!R;V=N86UE.PI#3U)%.CIE>&ET*"0Q*2!I9B`H)$`@/7XO7E]42U]%
M6$E47UPH*%QD*RE<*2\I.PID:64@)$`@:68@)$`["GT["B0Z.E]?15)23U(@
M/2`D0"!I9B`D0#L*?0I#3U)%.CIE>&ET*"0Q*2!I9B`H)#HZ7U]%4E)/4B`]
M?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D.CI?7T524D]2(&EF("0Z
M.E]?15)23U(["C$["E]?14Y$7U\*``$;`SOP````'0```#!Q__\,`0```'7_
M_S`!```0=?__D`T``)!X__]$`0``<*#__X@!```PH?__[`$``,"A__\D`@``
M$*3__Z0"``"0I?__7`,``#"F___,`P``(*?__V@$``!@I___F`0``,"G___D
M!```@*C__W0%``"0J/__B`4``,"J__^$!@``\*K__Y@&``#@J___"`<``+"M
M__]`!P``,*[__V0'``!PKO__D`<``$"O___\!P``X+O__]0+``!PO___2`T`
M`-^____8#0``\+___^P-```PP/__(`X``)#`__]L#@``H,#__X`.```4````
M``````%Z4@`!?`@!&PP$!(@!```@````'````!QP___0`P````X(1@X,2@\+
M=`1X`#\:.RHR)"(0````0````,AS__\0`````````$````!4````1'?__]\G
M````00X(A0)!#@R'`T0.$(8$00X4@P5&#J`&`\@G"@X40<,.$$'&#@Q!QPX(
M0<4.!$$+````8````)@```#@GO__O`````!!#@B%`D$.#(<#00X0A@1!#A2#
M!4X.,`)!#C1!#CA$#CQ!#D!(#C!7"@X40\,.$$'&#@Q!QPX(0<4.!$(+;@H.
M%$/##A!!Q@X,0<<."$'%#@1$"S0```#\````/)___X(`````00X(AP)!#@R&
M`T,.$(,$3@X@`F8*#A!!PPX,0<8."$''#@1!"P``?````#0!``"4G___2P(`
M``!!#@B%`D$.#(<#0PX0A@1!#A2#!5`.3%<.4$@.0%D.3$,.4$@.0`)/#DQ-
M#E!(#D`">`H.%$'##A!!Q@X,0<<."$'%#@1'"P)<#DQ+#E!(#D!2#D1!#DA)
M#DQ%#E!0#D!C#DA!#DQ!#E!0#D````"T````M`$``&2A__]R`0```$$."(4"
M00X,AP-##A"&!$$.%(,%40Z@`6T*#A1!PPX00<8.#$''#@A!Q0X$2`M##JP!
M00ZP`4@.H`%;#JP!00ZP`4@.H`%W#JP!1`ZP`6L.K`%!#J@!10ZL`40.L`%$
M#K0!0@ZX`4(.O`%!#L`!2`ZD`44.J`%!#JP!0@ZP`4@.H`%8#JP!00ZP`4@.
MH`%##JP!00ZP`4@.H`%0#JP!00ZP`5`.H`$`;````&P"```LHO__F`````!!
M#@B'`D$.#(8#0PX0@P1.#AQ(#B!(#A1&#AA!#AQ"#B!(#A!%"L,.#$/&#@A!
MQPX$0PM##AQ"#B!.#A!/#AQ"#B!.#A!/#AA"#AQ!#B!(#A!&PPX,1,8."$''
M#@0``)@```#<`@``7*+__^<`````00X(A0)!#@R'`T,.$(8$00X4@P51#L0@
M6`[(($L.S"!!#M`@2`[`(&,.Q"!!#L@@0@[,($$.T"!(#L`@2P[,($$.T"!&
M#M0@00[8($$.W"!!#N`@2`[`(%8*#A1!PPX00<8.#$''#@A!Q0X$1PM+#LP@
M00[0($@.Q"!$#L@@00[,($$.T"!(#L`@`"P```!X`P``L*+__SL`````00X(
M@P).#AQ(#B!,#B1,#BA!#BQ!#C!(#@A!PPX$`$@```"H`P``P*+__U,`````
M00X(A@)!#@R#`TX.'$@.($X.'$(.($8.'$<.&$(.'$$.($$.)$<.*$<.+$$.
M,$@.#$'##@A!Q@X$``",````]`,``-2B__^Y`````$$."(4"00X,AP-!#A"&
M!$$.%(,%40ZP0%T.N$!!#KQ`00[`0$<.Q$!%#LA`0@[,0$4.T$!(#K1`10ZX
M0$@.O$!!#L!`2`ZP0$P.O$!!#L!`2`ZP0$D.M$!!#KA`00Z\0$$.P$!-#K!`
M6`H.%$'##A!!Q@X,0<<."$'%#@1!"P`0````A`0```2C__\%`````````/@`
M``"8!````*/__R4"````00X(A0)!#@R'`T$.$(8$00X4@P51#M`@<P[8($0.
MW"!!#N`@2`[0('$*#A1!PPX00<8.#$''#@A!Q0X$1@M##MP@1`[@($8.W"!!
M#M@@3P[<($$.X"!(#M`@<0[8($$.W"!!#N`@2`[0($L.W"!!#N`@2`[0('4.
MU"!$#M@@00[<($<.X"!!#N0@10[H($(.["!%#O`@2`[<($8.X"!(#M0@1@[8
M($$.W"!"#N`@2`[0($<.W"!"#N`@3@[0($\.V"!$#MP@0@[@($@.T"`"10[8
M($(.W"!!#N`@2`[0(%0.W"!!#N`@2`[0(!````"4!0``-*3__RH`````````
M;````*@%``!0I/__Z`````!!#@B&`D$.#(,#3@X@5@XL00XP3`X@8`XL0@XP
M2`X@3PH.#$'##@A!Q@X$0@M>#BQ!#C!(#B!J#B1!#BA!#BQ'#C!(#B!%"@X,
M0<,."$'&#@1'"T,.#$/##@A!Q@X$`#0````8!@``T*3__\0!````00X(AP)!
M#@R&`T$.$(,$3@Y``V`!"@X00<,.#$'&#@A!QPX$1`L`(````%`&``!HIO__
M=@````!!#@B#`DX.(&<*#@A!PPX$20L`*````'0&``#$IO__-`````!!#@B#
M`DX.$$@.'$$.($@.$$D*#@A!PPX$1@MH````H`8``-BF___'`````$$."(4"
M00X,AP-!#A"&!$$.%(,%3@XP;0XX00X\00Y`2`XP1PX\00Y`9@XT00XX00X\
M1PY`00Y$0@Y(0@Y,00Y03@XP:0H.%$'##A!!Q@X,0<<."$'%#@1!"P#4`P``
M#`<``#RG__^1#````$$."(4"00X,AP-!#A"&!$$.%(,%40[0@@("P@[<@@)!
M#N""`E@.T(("5P[<@@)$#N""`D$.Y(("0@[H@@)"#NR"`D$.\(("2P[0@@)[
M#MR"`D$.X(("2`[0@@)^#MR"`D$.X(("2`[0@@))#MR"`D$.X(("2`[0@@("
M0P[<@@)*#N""`E(.Y(("00[H@@)+#NR"`D<.\(("0P[T@@)"#OB"`D(._(("
M00Z`@P)(#MB"`D4.W(("00[@@@)(#M""`EX.W(("0@[@@@)(#M2"`D8.V(("
M1`[<@@)"#N""`D@.T(("20[<@@)$#N""`D8.Y(("1P[H@@)(#NR"`D(.\(("
M2`[0@@)F"@X40<,.$$'&#@Q!QPX(0<4.!$4+4P[<@@)"#N""`DX.T(("4P[<
M@@)"#N""`E<.T(("30[<@@)"#N""`DX.T(("4P[<@@)!#N""`EL.T(("2P[<
M@@)!#N""`D8.W(("00[8@@)!#MR"`D8.X(("3`[0@@)+#MR"`D4.X(("2`[0
M@@("0P[8@@)"#MR"`D0.X(("3`[0@@)K#M2"`D$.V(("2@[<@@)$#N""`D$.
MY(("0@[H@@)"#NR"`D0.\(("2`[0@@)D#MR"`D0.X(("00[D@@)!#NB"`D0.
M[(("1`[P@@)!#O2"`D(.^(("0@[\@@)!#H"#`D@.T(("0P[8@@)%#MR"`D$.
MX(("2`[0@@)(#MR"`D0.X(("80[0@@),#MR"`D$.X(("7`[0@@)P#MR"`D@.
MX(("3`[0@@)/#MR"`D$.X(("2`[0@@)F#M2"`D(.V(("0@[<@@)%#N""`D@.
MU(("0@[8@@),#MR"`D$.X(("2`[0@@):#M2"`D(.V(("0@[<@@)$#N""`@*M
M#M""`EH.U(("10[8@@)$#MR"`D0.X(("2`[0@@("F@[4@@)!#MB"`D0.W(("
M0P[@@@)8#M""`@,1`0[4@@)!#MB"`D$.W(("1`[@@@)/#M""`EL.W(("1`[@
M@@("1@[0@@(#Y`$.W(("00[@@@)!#N2"`D(.Z(("0@[L@@)!#O""`DL.T(("
M50[4@@)*#MB"`D0.W(("1`[@@@)!#N2"`D(.Z(("0@[L@@)$#O""`D@.T(("
M5P[<@@)!#N""`DP.T(("`F8*#MB"`D$.W(("1`[@@@)&#N2"`DL+`G(.U(("
M0@[8@@)"#MR"`D4.X(("2`[4@@)"#MB"`D4.W(("00[@@@),#N2"`D<.Z(("
M1`[L@@)$#O""`D$.](("0@[X@@)"#OR"`D0.@(,"2`[0@@)P`0``Y`H```2P
M__^&`P```$$."(4"00X,AP-!#A"&!$$.%(,%3@Y,5`Y01@Y,0@Y09@Y`50Y,
M0@Y030Y40@Y800Y<00Y@2`Y`<@Y(1`Y,20Y03`Y`6@Y,00Y01PY400Y81`Y<
M00Y@2`Y`7@Y,00Y01PY40@Y810Y<00Y@2@Y`=@Y,1`Y01@Y,00Y(00Y,00Y0
M2`Y`30Y,00Y030Y40@Y800Y<00Y@2`Y`3`Y,1`Y03@Y$00Y(00Y,00Y02PY`
M3PY,0@Y030Y40@Y800Y<00Y@2`Y`90Y,1`Y02`Y$00Y(00Y,00Y02`Y`0PY,
M0@Y03@Y$0@Y(00Y,00Y02`Y,0@Y03@Y$00Y(00Y,00Y01@Y,0@Y06PY`3PY(
M10Y,00Y02PY`8@H.%$'##A!!Q@X,0<<."$'%#@1*"T,*#DQ&#E!(#D!5#DQ!
M#E!)"UD.3$D.4%$.0%`.3$(.4$8.3$$.2$$.3$$.4$@.0$L.1$<.2$(.3$<.
M4`!$````6`P``""R__]O`````$$."(<"00X,A@-!#A"#!%(.'$$.($L.$`)!
M"L,.#$'&#@A!QPX$00M#PPX,0<8."$''#@0```!$````H`P``'AG__\\`@``
M`$0,`0!'$`4"=0!&#P-U<`80!P)U?!`&`G5X$`,"=70#=P$*P0P!`$'#0<9!
MQT'%0PP$!$$+```0````Z`P``/^Q__\$`````````#````#\#```_+'__SP`
M````00X(@P).#A!-#A1$#AA$#AQ$#B!(#@A!PPX$1PX0@P(```!(````,`T`
M``BR__]=`````$$."(4"00X,AP-!#A"&!$$.%(,%3@X@:0XD1`XH1`XL00XP
M30X@1PX40<,.$$'&#@Q!QPX(0<4.!```$````'P-```<LO__`@`````````8
M````D`T``!BR__\4`````$$."(,"3@X0````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````0!D`
M`/`8```!`````0````$```#+`0```0```-8!```!````X`$```$````O`@``
M`0```(P#```,````P!$```T```!T80``&0```*C-```;````!````!H```"L
MS0``'`````0```#U_O]OK`$```4```#L"```!@```(P"```*````_@0```L`
M```0````%0`````````#````T,X```(```#@`0``%````!$````7````X`\`
M`!$```!8#P``$@```(@````3````"````!X````(````^___;P$```C^__]O
MN`X``/___V\"````\/__;^H-``#Z__]O!0``````````````````````````
M``````````````````````````````"PS0`````````````&$@``%A(``"82
M```V$@``1A(``%82``!F$@``=A(``(82``"6$@``IA(``+82``#&$@``UA(`
M`.82``#V$@``!A,``!83```F$P``-A,``$83``!6$P``9A,``'83``"&$P``
MEA,``*83``"V$P``QA,``-83``#F$P``]A,```84```6%```)A0``#84``!&
M%```5A0``&84``!V%```AA0``)84``"F%```MA0``,84``#6%```YA0``/84
M```&%0``%A4``"85```V%0``1A4``%85``!F%0``=A4``(85``"6%0``IA4`
M`+85``````````````````````````````````````````````````#0%0``
M``````````````````````30``#_____C&0``$=#0SH@*$1E8FEA;B`W+C(N
M,"TQ,2D@-RXR+C``1T-#.B`H1&5B:6%N(#8N-"XP+30I(#8N-"XP(#(P,3<P
M.#(P```N<VAS=')T86(`+FEN=&5R<``N;F]T92Y!0DDM=&%G`"YN;W1E+F=N
M=2YB=6EL9"UI9``N9VYU+FAA<V@`+F1Y;G-Y;0`N9'EN<W1R`"YG;G4N=F5R
M<VEO;@`N9VYU+G9E<G-I;VY?<@`N<F5L+F1Y;@`N<F5L+G!L=``N:6YI=``N
M<&QT+F=O=``N=&5X=``N9FEN:0`N<F]D871A`"YE:%]F<F%M95]H9'(`+F5H
M7V9R86UE`"YI;FET7V%R<F%Y`"YF:6YI7V%R<F%Y`"YD>6YA;6EC`"YD871A
M`"YB<W,`+F-O;6UE;G0`````````````````````````````````````````
M````````````````"P````$````"````5`$``%0!```3```````````````!
M`````````!,````'`````@```&@!``!H`0``(```````````````!```````
M```A````!P````(```"(`0``B`$``"0```````````````0`````````-```
M`/;__V\"````K`$``*P!``#@````!0`````````$````!````#X````+````
M`@```(P"``",`@``8`8```8````!````!````!````!&`````P````(```#L
M"```[`@``/X$``````````````$`````````3@```/___V\"````Z@T``.H-
M``#,````!0`````````"`````@```%L```#^__]O`@```+@.``"X#@``H```
M``8````"````!`````````!J````"0````(```!8#P``6`\``(@````%````
M``````0````(````<P````D```!"````X`\``.`/``#@`0``!0```!8````$
M````"````'P````!````!@```,`1``#`$0``(P``````````````!```````
M``!W`````0````8```#P$0``\!$``-`#`````````````!`````$````@@``
M``$````&````P!4``,`5```0```````````````(````"````(L````!````
M!@```-`5``#0%0``I$L`````````````$`````````"1`````0````8```!T
M80``=&$``!0```````````````0`````````EP````$````"````B&$``(AA
M```X/P`````````````$`````````)\````!`````@```,"@``#`H```]```
M````````````!`````````"M`````0````(```"TH0``M*$``*P-````````
M``````0`````````MP````X````#````J,T``*B]```$```````````````$
M````!````,,````/`````P```*S-``"LO0``!```````````````!`````0`
M``#/````!@````,```"PS0``L+T``"`!```&``````````0````(````A@``
M``$````#````T,X``-"^```P`0`````````````$````!````-@````!````
M`P````#0````P```$```````````````!`````````#>````"`````,````@
MT```$,```#00`````````````"``````````XP````$````P`````````!#`
M``!"```````````````!`````0````$````#``````````````!2P```[```
1`````````````0``````````
